#!/usr/bin/perl
#!c:/perl/bin/perl.exe
# The above line may need to be changed to reflect the location of
# the perl interpreter on your system.  Use "which perl" on a Unix system
# to make a noble attempt to locate your perl interpreter.  If you are
# installing this on an NT IIS server then you probably do not need to
# modify this line because it will most likely be ignored.  Apache under
# NT generally DOES require the top line to be configured.  We have provided
# two common paths above as examples, only the top line will be used, the
# second line is just there to provide an example.

############################################################################
# MailMan, Professional Edition, version 3.0.22
#
# Copyright (c) 1996 - 1999, Endymion Corporation. All rights reserved.
# Endymion Corporation: http://www.endymion.com/
# Originally by Ryan Alyn Porter, rap@endymion.com
#
# This product is not free and is not in the public domain.
# For detailed information on the licensing structure of MailMan, see
# http://www.endymion.com/products/mailman/
#
# Initiated:      9/07/1997 Version 1.1
# Re-awakened:    4/24/1998 Version 2.0 beta
# Released:       7/20/1998 Version 2.0
# Last Modified:  3/29/2000 Version 3.0.22
############################################################################

# If you are having problems with MailMan not working at all, please
# take a look at the MailMan FAQ, stored online at
# http://www.endymion.com/products/mailman/faq.htm.  A version of the FAQ
# should also have been in the distribution that contained this file.

package mailman;

# Enable these while you are working on modifications.  Make absolutely
# certain that 'use strict' is NOT enabled in production installations.
# CGI.pm and 'use strict' are not compatible, if you have 'use strict'
# enabled then your users will not be able to upload files because CGI.pm
# provides uploaded files using a bizarre on-the-fly file handle that will
# cause an error if you have 'use strict' enabled.  We think that this is
# ugly too, but there is no way around it at the moment.
#use strict;
#$^W = 1; # Warnings.

# Version information that might find its way into output.
$mailman::strMailManVersion = 'v3.0.22';
$mailman::strMailManEdition = 'Professional Edition';

# Variable initialization.  Clean and neat and all, but very necessary
# for mod_perl.
InitializeVars();

############################################################################
# This section contains a few variables that you might need to set  in order
# to get MailMan functioning properly.  If your installation is working,
# then you don't need to worry about any of these.
############################################################################

# Local Location Users
# IMPORTANT: Set this variable to point to a directory that you have 
# set up as the user storage area.  Make sure that your web user has
# read and write access to this directory.  This needs to be a path
# that makes sense at runtime for the web user, probably an absolute
# path like '/something/somewhere/mailman/users/' or 
# "C\:\\mailman\\users\\".  Note the terminal slash at the end.  That's
# important.  It won't work without that slash.  You probably shouldn't
# be storing your user messages in publicly readable areas of your
# web server for obvious security reasons, but some people don't have the
# option.  Just use your head, and ask us if you have any questions.
# Also PLEASE remember that the data that MailMan writes to this
# directory should be considered irreplacable user data and should be
# handled and backed up appropriately.
$mailman::strLocalLocationUsers = 'users/';

# User Disk Quota
# This is fairly self-explanatory, it's the number of bytes that users
# are allowed to use on your HTTP server for storing messages.  If this
# value is set to zero then no quota will be maintained and users will
# never see quota status indicators.  You can turn this on and off and
# mess with the size at will, but note that if you decrease the quota
# size after users have downloaded stuff then you could put some users
# over quota.  We have taken care to gracefully handle this situation
# but your users might not think that things look very graceful when that
# happens.  Remember to set this in bytes.  1024*1024 bytes in a megabyte,
# some common values are as follows:
# 1  MB = 1048576 B
# 2  MB = 2097152 B
# 5  MB = 5242880 B
# 10 MB = 10485760 B
# Note that there are a couple of ways that a user can go slightly
# over quota.  MailMan allows this in cases like the storage of an
# outgoing message and the like where recovery from a quota error
# would be very difficult and un-graceful.  Quotas are primarily
# enforced when a user downloads new messages.  If you notice that a
# particular user has gone slightly over 100% of his/her quota, please
# don't consider that a bug in MailMan.  We have intentionally set things
# up this way.  This is a hint to administrators to allow for a little
# more room on storage systems than the sum of all users' quotas.
$mailman::iUserDiskQuota = 5242880;

# Management Password
# This password must be included in any query to verify or repair
# the message store database.
$mailman::strManagementPassword = 'changethis';

# Download Individual Accounts
# Use this variable to tell MailMan that it should only download messages
# from external accounts when the user explicitly issues a LOADACCOUNT
# command.  If this value is not set, MailMan will automatically download
# messages from all of a user's accounts when they log in.
#$mailman::bDownloadIndividualAccounts = 1;

# Case Insensitive Accounts
# This variable is used to indicate to MailMan that the POP3 account
# names are case insensitive, so "BOB", "Bob" and "bob" are all considered
# the same POP3 user.  This is important in locating the user's persistent
# information such as the message archive and the user's properties files.
$mailman::bCaseInsensitiveAccounts = 1;

# Location Attachments
# When a user selects an attachment from a message for downloading,
# MailMan generates that attachment on-the-fly and sends it through the
# HTTP server to the user's browser.  MailMan includes the necessary
# HTTP header information for the user's browser to determine the
# file name, but many broswers, most notably Microsoft's Internet
# Explorer, either ignore these headers or just don't handle them
# very well.  The result is that when a user downloads an attachment,
# your browser may present the user with a "Save As" box with the
# file name filled in as the name of this script, a string or random
# characters, or any number of other un-graceful things.  We think that
# the best solution to this problem would be for browser makers to
# pay attention to HTTP headers, but until then we provide a mechanism
# for working around the problem.  If you set up a directory that is
# writable by MailMan and readable by your web server, then MailMan
# will write out the attachment file to that directory temporarily,
# and redirect the user's browser to that file.  When the user logs
# in or out MailMan will ensure that the user's files in this
# temporary directory are removed.  A user that exits MailMan without
# logging out and never logs back in could potentially leave stale
# attachment files on the server, so occasional monitoring of the
# temporary directory for stale files would be appropriate.  Also note
# that this mechanism could be considered a privacy problem since a
# user's attachments are deposited temporarily into a world-readable
# directory rather than generated on-the-fly the way MailMan normally
# would do.  We have left the decision up to each individual
# administrator as to whether or not to use this feature.  Most people
# seem to prefer allowing MailMan to generate attachments on-the-fly
# for simplicity, ease of administration, and security/privacy, but
# some people think that the attachment file name thing is a critical
# issue.  The decision is yours.
# To use this feature, create a directory that is readable by your
# web server and writable by the user that MailMan runs as.  Set
# $mailman::strLocalLocationAttachments to the local path name of 
# this directory, for instance
# $mailman::strLocalLocationAttachments = '/public_html/attachtmp/';
# Then set $mailman::strURLLocationAttachments to the URL location
# of this directory, for instance
# $mailman::strURLLocationAttachments = '/attachtmp/';
# Note the terminal slashes at the end, those are necessary.  Just
# set and uncomment the following lines to use this feature:
#$mailman::strLocalLocationAttachments = 'c:/www/public_html/mailman/tmp/';
#$mailman::strURLLocationAttachments = '/mailman/tmp/';

# Local File Permissions
# Use this if you want to modify the permissions that files and
# directories created by MailMan use.  This will only make much sense
# to Unix and Unix-like operating systems.  If this value is not set,
# nothing will happen.  This should be an octal integer as in the
# example below, not a string.
$mailman::iLocalFilePermissions = 0666;

# Local Directory Permissions
# Same as above, used for directories created by MailMan.
$mailman::iLocalDirectoryPermissions = 0777;

# Outgoing Banner Text
# This is the banner that is appended to the end of any message that
# this MailMan installation sends.  One reason why this is one of the
# first configuration options is because we want to make it very 
# obvious that you can remove or modify this banner.  Endymion places
# no restrictions at all on this banner, so don't worry about leaving
# credit to us in here or anything like that.  Please feel free to 
# change this to whatever you like, or completely remove it.  If this
# value is not defined then it will simply append no banner.
$mailman::strOutgoingBannerText = 
    "\n" .
    "---------------------------------------------\n" .
    "This message was sent using Endymion MailMan.\n" .
    "http://www.endymion.com/products/mailman/\n";

# Incoming Mail Server:
# The way that we originally intended to allow people to 'rig' the server
# names for an installation was through simple template modifications, as
# mentioned in the FAQ.  A lot of people have asked about ways to rig the
# server names in the script itself though, so we added this.  We aim to
# please...  If you want to rig your incoming server name so that it makes
# no difference at all what an incoming form specifies, just un-comment
# this line and specify it.
#$mailman::strIncomingServer = 'mail.endymion.com';

# Outgoing Mail Server:
# Same deal, different server.
#$mailman::strOutgoingServer = 'mail.endymion.com';

# From Domain Name:
# Set this variable to override the domain name that is assumed when a
# user logs in.  For instance, when the user "rap" logs into the POP3
# server "mail5.it.endymion.com", MailMan will assume that his address
# is "rap@mail5.it.endymion.com".  If you set this variable to
# "endymion.com", then it will assume that his address is
# "rap@endymion.com" instead.  If the mapping between POP3 user names
# and email addresses is more complicated then you will need to actually
# build your own routines to do the mapping.  For instance, if the user
# "endy-rap" at the POP3 server "shell1.ba.best.com" actually receives
# mail at the address "rap@endymion.com", then you will need to do make
# your own custom mapping routine to deal with this.
#$mailman::strFromDomainName = "endymion.com";

# From Domain Trim:
# If the above option doesn't work for you, you can set this value to
# instruct MailMan to trim the machine name when it derives the 'from'
# email address.  The number that you set this to represents the total
# number of names to shear off of the left-hand side of the machine
# name.  For instance, if the user's POP3 server name is
# "mail.rex.endymion.com", and you set this value to 0, the default,
# then when the user composes a message MailMan will guess
# "username@mail.rex.endymion.com" as the 'from' address.  If you set
# this value to 1 then it will guess "username@rex.endymion.com", if
# you set it to 2 then it will guess "username@endymion.com", etc.  This
# can be helpful if you have a number of different virtual domains
# and you want the email address to be inferred dynamically, rather
# than by hard-coding it with the "From Domain Name" configuration value.
$mailman::iFromDomainTrim = 0;

# Outgoing Domain Name:
# When a user specifies a recipient name without full domain qualification
# ("rap" instead of "rap@endymion.com", for example) then the SMTP server
# should provide configuration rules for determining how to deal with this
# mail.  It should not be the responsibility of the mail client to fill in
# a complete address.  We have had many requests for a feature to allow 
# an administrator to specify a default domain name, however, and we aim
# to please.  This configuration variable is the result.  If you want
# MailMan to assume a default domain name when it is given an incomplete
# address, uncomment this line and set it to your domain name.  We strongly
# recommend against this, however, you should be looking into your SMTP
# server's configuration options and not using this feature.
#$mailman::strOutgoingDomainName = 'endymion.com';

# Messages Per Page:
# This value controls the number of messages returned per page in a
# message list.  Adjust it if you like.
# The user has the option of overriding this value in the user preferences
# page.  If you don't want them to be able to do this you can hide that
# field in your templates.
$mailman::iMessagesPerPage = 10;

# Local Template Location:
# If you have a web server that sets the current directory to something
# strange, you can set this to an absolute path to make it easier to
# allow MailMan to find the templates.  Just set this variable to an
# absolute path like "C\:\\inetpub\\wwwroot\\mailman\\templates\\"
# or '/usr/home/rap/mailman/' or whatever.  Note the final slash, that's
# important.  If you leave it out then things won't work.  If you need
# to set this value, then un-comment the following line:
#$mailman::strLocalTemplateLocation = "D:/inetpub/wwwroot/Endymion2/products/mailman/demo/";

# Local Script Location:
# If your server is one of the ones that causes problems that require the
# above value to be set, then you might also need to set this value.  In
# most cases your script location and your template location will be 
# identical, but if you move your templates to a different directory than
# your script for whatever reason, then you will need to set this.  If you
# have no idea what I'm talking about, you should probably just leave this.
$mailman::strLocalScriptLocation = $mailman::strLocalTemplateLocation;

# URL Image Location:
# Use this to rig the URLs that will be used to access the images that
# the templates point to.  This value will be prepended to any value in
# the templates of the form ""i_*.gif"" (including the inner quotes).
# If you have customized your templates and your own custom images are
# not showing up in MailMan's output, it is probably because the custom
# images that you are using are not named "i_*.gif".
# To use this variable, set it to the exact value that you want prepended
# to image names in order to make them into URLs that will point to your
# image directory.  For instance, if you bury your images in an "images"
# directory under the directory where MailMan is installed, set this to
# 'images/' (with the slash).  If you put your images in a completely
# different directory, something that is rooted, like '/mailman/images/'
# might be what you are looking for.  In the most extreme cases you can
# do away with relative URLs entirely and provide a complete absolute URL
# like the one below
#$mailman::strURLImageLocation = 'http://www.endymion.com/images/';

# Use Perl 'alarm()' function:
# Set this to true if your Perl interpreter supports "alarm".  As of this
# Writing, NT Perl does not.  If this is not set, MailMan will not be able
# to timeout when a server hangs.  The OSSettings() routine will attempt
# to set this variable, but you can override it here if you want.
# The point of the "alarm" feature as used in MailMan is to allow MailMan
# to detect when a mail server has not responded within a reasonable
# amount of time.  If your server's Perl interpreter does not support
# "alarm", then MailMan will still work, but if a mail server ever does
# not respond then the user will get no feedback to that effect.
#$mailman::bUseAlarm = 1;

# Timeout Duration:
# The aforementioned timeout delay.  Set this to something else to modify
# how long MailMan will sit around waiting for a mail server to respond.
# Only works if $mailman::bUseAlarm is set to something.
$mailman::iTimeoutDurationInSeconds = 180;

# Use Perl 'crypt()' function:
# Some Perl impelentations apparently do not support the crypt() function.
# We have never seen one, and there are plenty of implementations out there
# that you should be able to find a good one, but we try to accomodate
# anyway.  Comment out this line if your Perl implementation is breaking
# on the crypt() function.  Be warned that if you do this your users'
# usernames and passwords will be less obfuscated than they were before,
# which admittedly wasn't much.  This is a good place to repeat the 
# suggestion that MailMan is an excellent candidate for SSL and other
# fancy HTTP security mechanisms.
#$mailman::bUseCrypt = 1;

# Use Hijack Test:
# MailMan performs a test to determine if the current session has been
# hijacked by a different user from a different address.  On a few 
# systems this will not work because of the configuration.  If your
# MailMan installation sits behind a cluster of caching proxy servers
# for load balancing, for instance.  If you want to disable the hijack
# checking functionality, just comment out this line.
#$mailman::bUseHijackTest = 1;

# Kiosk Mode:
# If you are using MailMan in a kiosk environment, it will generally
# be possible for a user to use a combination of "BACK" and "RELOAD" in
# the kiosk web browser to intrude backwards into the mail sessions of
# previous users.  If you set this value then MailMan will operate in
# kiosk mode, which means that when a user logs in, MailMan will create
# a new browser window with that user's session.  If the user logs out
# then that window will close, and the user's history information will
# go with the window so that intrusions with "BACK" and "RELOAD" aren't
# possible.  We recommend against using this feature for installations
# that are not kiosk-based because it relies on Javascript and cookies,
# which does not leave users with older browsers with a way in.  If you
# are in a kiosk environment then you have control over the browser an
# that's not a problem.  We strongly recommend against using the
# Microsoft Internet Explorer for kiosk environments because it does not
# properly respect the "Expires:" and "Cache-control:" HTTP headers, so
# IE will cache user mail to the hard drive whether you want it to or
# not.  Microsoft appears to have no interest in fixing this problem.
# IE 4 SP1 pretty consistently crashed during our tests of the 
# full-screen popup window kiosk mode, too, which is likely not exactly
# the behavior that you are looking for in your kiosk browser.
# The kiosk mode feature primarily activates and deactivates sections
# of outbound templates, so if you have customized your templates before
# you decided to use kiosk mode then it is entirely possible that you
# broke this mode by removing vital Javascript.  Consult the
# out-of-the-box template set for examples of the Javascript snippets
# necessary for this mode.
#$mailman::bKioskMode = 1;

############################################################################
# You should not have to configure any values after this line.
############################################################################

use Socket; use FileHandle; my($mma) = new FileHandle(); use CGI;
my($mmb) = new CGI; {  my(@mmc) = $mmb->param; my($mmd) = 0;
for($mmd=0;$mmd<$#mmc+1;$mmd++) { my($mme) = $mmc[$mmd];;
if($mme =~ /^(.+)\.[xy]$/) { my($mmf) = $1; if($mme =~ /^([^\#]+)\#(.*)\.[xy]$/) {
$mmf = $1; $mmb->param($mmf,mmsy($2)); } else {
$mmb->param($mmf,'MAILMANSPECIALTRUE'); } $mmb->delete("${mmf}.x");
$mmb->delete("${mmf}.y"); } else { if($mme =~ /^([^\#]+)\#(.*)$/) {
$mmb->param($1,mmsy($2)); } } } } if($mmb->param('INTERFACE')) {
my(@mmg) = split(/\&/,$mmb->param('INTERFACE')); my($mmh) = '';
foreach $mmh (@mmg) { if($mmh =~ /^([^\=]+)\=(.*)$/) {
$mmb->param($1,mmsy($2)); } }
unless($mmb->param('INTERFACE') =~ /ALTERNATE_TEMPLATES/) {
$mmb->param('ALTERNATE_TEMPLATES',''); } } {
@mailman::mmi = split(/\;/,$ENV{'HTTP_COOKIE'}); my($mmj) = '';
foreach $mailman::mmj (@mailman::mmi) { $mailman::mmk = 1;
if($mailman::mmj =~ /MailManAuth\=(\S+)/) { my(@mml) = split(/\&/,$1);
my($mmm) = ''; foreach $mmm (@mml) { $mmm =~ /^(.+)\#(.+)$/; unless($mmb->param($1))
{ $mmb->param($1,$2); } } } if($mailman::mmj =~ /MailManDir\=(\S+)/) {
$mailman::mmn = mmsy($1); } } }
$mailman::mmo = mmtc($mmb->param('USERNAME'));
$mailman::mmo =~ s/^\s*([^\s]+)\s*$/$1/; 
$mailman::mmp = mmtb($mailman::mmo);
$mailman::mmq = mmtc($mmb->param('PASSWORD'));
$mailman::mmq =~ s/^\s*([^\s]+)\s*$/$1/; 
$mailman::mmr = mmtb($mailman::mmq); unless($mailman::strIncomingServer) {
$mailman::strIncomingServer =  mmtc($mmb->param('SERVER'));
$mailman::strIncomingServer =~ s/^\s*([^\s]+)\s*$/$1/;  }
$mailman::mms = mmtb($mailman::strIncomingServer);
unless($mailman::strOutgoingServer) {
$mailman::strOutgoingServer = $mmb->param('OUTGOING');
$mailman::strOutgoingServer =~ s/^\s*([^\s]+)\s*$/$1/;  } $mailman::mmt = '';
unless($mailman::strLocalLocationUsers =~ /[\/\\]$/) {
$mailman::strLocalLocationUsers .= '/'; } $mailman::mmu = $mailman::mmo . '@' .
$mailman::strIncomingServer; $mailman::mmu =~ tr/[A-Z]/[a-z]/;
$mailman::mmv = $mailman::strLocalLocationUsers . mmsx($mailman::mmu);
if(defined($mailman::strLocalLocationAttachments) &&
defined($mailman::strURLLocationAttachments)) {
unless($mailman::strLocalLocationAttachments =~ /[\/\\]$/) {
$mailman::strLocalLocationAttachments .= '/'; }
unless($mailman::strURLLocationAttachments =~ /[\/\\]$/) {
$mailman::strURLLocationAttachments .= '/'; } $mailman::mmw =
$mailman::strLocalLocationAttachments . mmsx($mailman::mmo .
'@' . $mailman::strIncomingServer); $mailman::mmx =
$mailman::strURLLocationAttachments . mmsx(
mmsx($mailman::mmo . '@' . $mailman::strIncomingServer));
$mailman::mmy = 1; } $mailman::mmz = mmsw($ENV{SERVER_NAME},42);
$mailman::mmz .= mmsw($ENV{REMOTE_HOST} . $ENV{REMOTE_ADDR},69);
$mailman::mmaa = mmtb($mailman::mmz); mmsv();
$mailman::mmab = $ENV{SCRIPT_NAME}; unless($mailman::mmab =~ /^\//) {
$mailman::mmab = "/$mailman::mmab"; } $mailman::mmac = $mailman::mmab;
$mailman::mmac =~ s/^(.*[\\\/])[^\\\/]+$/$1/; if($mailman::mmac eq '/') {
$mailman::mmad = ''; } else { $mailman::mmad = "path=$mailman::mmac; "; }
sub mmqb { if($mmb->param('NOFRAMES')) { $mailman::mmae = 1; }
if($mmb->param('NOCACHE')) { $mailman::mmaf = 1; }
if(defined($mmb->param('ALTERNATE_TEMPLATES'))) { $mailman::mmag = 
$mmb->param('ALTERNATE_TEMPLATES'); } if(!defined($mailman::mmah)) {
$mailman::mmah = mmsy($mmb->param('FOLDER')); }
if(($mailman::mmah eq '') && ($mailman::mmn ne '')) {
$mailman::mmah = $mailman::mmn; } } sub mmqc { my($mmai) = shift;
my(@mmc) = $mmb->param; my($mmd) = 0; for($mmd=0;$mmd<$#mmc+1;$mmd++) {
my($mme) = $mmc[$mmd];; if($mme =~ /^$mmai\:(.*)$/) { return $1; } } return; }
mmqb(); mmqd(); { my($mmj) = '';
@mailman::mmi = split(/\;/,$ENV{'HTTP_COOKIE'});
foreach $mailman::mmj (@mailman::mmi) { if($mailman::mmj =~ /MailManCmds\=(\S+)/) {
my($mmaj) = ''; @mailman::mmak = split(/\&/,$1); foreach $mmaj (@mailman::mmak) {
$mmaj =~ /^(.+)\#(.+)$/; unless($mmb->param($1)) { $mmb->param($1,$2); } } } } }
mmqb(); mmqd(); mmqg();
sub mmqd { my($mmal) = ''; if($mmb->param('BLANK')) {
mmsu('t_blank.htm'); } if($mmb->param('MENU')) {
mmsu('t_f_menu.htm'); } if($mmb->param('LOGOUT')) { if($mailman::mmy) {
mmts(); } if($mailman::bKioskMode) {
print "Set-cookie: MailManAuth=;$mailman::mmad" .
"expires=Sun, 03-May-1998 16:00:00 GMT\n";
print "Set-cookie: MailManCmds=;$mailman::mmad" .
"expires=Sun, 03-May-1998 16:00:00 GMT\n";
print "Set-cookie: MailManDir=;$mailman::mmad" .
"expires=Sun, 03-May-1998 16:00:00 GMT\n"; $mailman::mmo = '';
mmsu('t_closewindow.htm'); } else { mmqg(); } }
if($mmb->param('START')) { mmqg(); } if($mmb->param('PREFERENCES')) {
mmqx(); } if($mmb->param('SAVEPREFERENCES')) { mmqy();
$mailman::mmam = $mmb->param('PREF_REALNAME');
$mailman::mman = $mmb->param('PREF_EMAIL');
$mailman::mmao = $mmb->param('PREF_SIGNATURE');
$mailman::mmap = $mmb->param('PREF_OUTGOING');
if($mmb->param('PREF_NUMPERPAGE') =~ /^\s*(\d+)\s*$/) { $mailman::mmaq = $1; }
if($mmb->param('PREF_DELETEDOWNLOAD')) { $mailman::mmar = 1; } else {
$mailman::mmar = 0; } if($mmb->param('PREF_DELETEPROXY')) { $mailman::mmas = 1; } else
{ $mailman::mmas = 0; } if($mmb->param('PREF_DELETESAVE')) { $mailman::mmat = 1; } else
{ $mailman::mmat = 0; } if($mmb->param('PREF_SENDSAVE')) { $mailman::mmau = 1; } else {
$mailman::mmau = 0; } if($mmb->param('PREF_STARTUP')) { $mailman::mmav =
$mmb->param('PREF_STARTUP'); } mmqz(); $mmb->param('LOGIN',1); }
if($mmb->param('FOLDERS')) { mmqw(); } if($mmb->param('FOLDERCHANGE')) {
if($mmb->param('FOLDERCHANGE') ne 'MAILMANSPECIALTRUE') {
$mailman::mmah = mmsy( $mmb->param('FOLDERCHANGE')); }
elsif(defined($mmb->param('FOLDERCHANGELIST')) &&
!($mmb->param('FOLDERCHANGELIST') eq 'MAILMANSPECIALSELECT')) { $mailman::mmah =
mmsy($mmb->param('FOLDERCHANGELIST')); }
if($mmb->param('FRAMERELOAD') && !($mailman::mmae)) {
mmsu('t_f_frameset.htm'); } else { if($mailman::mmah eq 'INBOX') {
mmqn(); } mmrp(); } } if($mmb->param('FOLDERNEW')) {
if($mmb->param('FOLDERNEWNAME')) { $mailman::mmah = $mmb->param('FOLDERNEWNAME');
mmql(); mmqm(); } mmqw(); }
if($mmb->param('FOLDERDELETE')) { my($mmaw) = $mailman::mmv . '/' .
mmsx($mmb->param('FOLDERDELETE')); if(mmtj($mmaw) == 0 &&
-d $mmaw) { opendir(DELETEDIR, $mmaw); my(@mmax) = readdir(DELETEDIR);
closedir(DELETEDIR); my($mmay); foreach $mmay (@mmax) { unlink("${mmaw}/${mmay}"); }
rmdir($mmaw); } $mailman::mmah = 'INBOX'; mmqw(); }
if($mmb->param('ADDRESSES')) { mmra(); }
if($mmb->param('ADDRESSCOMPOSE')) { my($mmaz) = ''; my($mmba) = '';
$mmba = $mmb->param('ADDRESSCOMPOSE'); mmrb();
if(defined($mailman::mmbb{$mmba})) { my($mmbc) =
$mailman::mmbb{$mmba}->{'FIRSTNAME'}; my($mmbd) =
$mailman::mmbb{$mmba}->{'LASTNAME'}; my($mmbe) =
$mailman::mmbb{$mmba}->{'ADDRESS'}; $mmaz =  "$mmbc $mmbd " .
"&lt;$mmbe&gt;"                } mmrc();
if(defined($mailman::mmbf{$mmba})) { $mmaz = $mailman::mmbf{$mmba};
$mmaz =~ s/(\r\n)|(\r\n)/,\ /g;  $mmaz =~ s/[\r\n]/,\ /g;        
$mmaz =~ s/\,\ $//g; } mmsl('NEW',undef,undef,$mmaz); }
if($mmb->param('ADDRESSESNEWINDIVIDUAL')) { mmrd(); }
if($mmb->param('ADDRESSDELETEINDIVIDUAL')) { mmrf(
$mmb->param('ADDRESSDELETEINDIVIDUAL')); mmra(); }
if($mmb->param('ADDRESSINDIVIDUAL')) { mmrd(); }
if($mmb->param('SAVEADDRESSINDIVIDUAL')) { mmrh();
mmra(); } if($mmb->param('ADDRESSESNEWGROUP')) {
mmre(); } if($mmb->param('ADDRESSDELETEGROUP')) {
mmrg( $mmb->param('ADDRESSDELETEGROUP')); mmra(); }
if($mmb->param('ADDRESSGROUP')) { mmre(); }
if($mmb->param('SAVEADDRESSGROUP')) { mmri(); mmra(); }
if($mmb->param('ACCOUNTS')) { mmrj(); } if($mmb->param('ACCOUNTNEW')) {
mmrk(); } if($mmb->param('ACCOUNTDELETE')) {
mmrm($mmb->param('ACCOUNTDELETE')); mmrj(); }
if($mmb->param('SAVEACCOUNT')) { mmrl(); mmqn();      
mmrj(); } if($mmb->param('ACCOUNT')) { mmrk(); }
if($mmb->param('DELETEACCOUNT')) { mmrm( $mmb->param('DELETEACCOUNT'));
mmrj(); } if($mmb->param('LOGIN')) { my($mmbg) = '';
if($mmbg = mmqi()) { if(defined($mmbg)) { $mmbg =~ s/^\-ERR(.*)$/$1/; }
$mailman::bKioskMode = 0; $mailman::mmbh{'GREETING'} = 
"<center><b>Log In Error: </b><i>$mmbg</i></center>";
mmsu('t_login.htm',\%mailman::mmbh); }

if(mmrv() <= 0){ mmrs(); exit(0); }
 if($mailman::mmy) {
mmts(); } mmqy(); if($mailman::mmae) {
mmqn(); if($mailman::mmav eq 'FOLDERS') { mmqw(); }
else { mmrp(); } } else { if($mailman::mmav eq 'FOLDERS') {
mmqw(); } else {

print eval(mmru($mailman::mhaa[0]));
 } } } if($mailman::bUseHijackTest && 
$mmb->param('CHECKSUM') &&  $mmb->param('CHECKSUM') ne '') {
if(mmtc($mmb->param('CHECKSUM')) ne $mailman::mmz) { mmqe(
qq|Your MailMan session was initiated from a different network address than\n| .
qq|your current location.  For security reasons, MailMan will not continue.\n| .
qq|You must <a href="MailMan(ME)?LOGOUT=TRUE" target="_top">log in again</a>\n| .
qq|from this location to continue.\n| ); } } if($mmb->param('RELOAD')) {
if($mailman::mmae) { mmqn(); mmrp(); } else {
mmsu('t_f_frameset.htm'); } } if($mmb->param('LOADACCOUNT')) {
mmqo($mmb->param('LOADACCOUNT')); if($mailman::mmae) {
mmrp(); } else { mmsu('t_f_frameset.htm'); } }
if($mmal = mmqc('LIST')) { if($mailman::mmah eq 'INBOX' ||
$mailman::mmah eq '') { mmqn(); } mmrp($mmal); }
if($mmb->param('LIST')) { if($mailman::mmah eq 'INBOX' || $mailman::mmah eq '') {
mmqp(); } mmrp(); }
my($mmbi) = $mmb->param('BACKGROUND'); if($mmbi) { if($mailman::mmae) {
print "Location: $mmbi\n\n"; exit(0); } else { mmro($mmbi); } }
if($mmbi = $mmb->param('BACKGROUNDFRAME')) {
mmsu('t_backgroundframe.htm'); } if($mmal = mmqc('SHOW')) {
my($mmbj) = -1; if($mmal =~ /^(.+)mimepart\:(.+)$/) { $mmbj = $1;
$mailman::mmbk = $2; $mailman::mmbk =~ s/%(..)/pack("c",hex($1))/ge; } else {
$mmbj = $mmal; } $mmbj = mmsy($mmbj); mmsd($mmbj,0); }
if($mmal = mmqc('SOURCE')) { my($mmbj) = mmsy($mmal);
mmse($mmbj); } if($mmal = mmqc('PREV')) {
my($mmbj) = mmsy($mmal); mmsd($mmbj,-1); }
if($mmal = mmqc('NEXT')) { my($mmbj) = mmsy($mmal);
mmsd($mmbj,1); } if($mmal = mmqc('DELETE')) {
my($mmbg) = mmqi(); if($mmbg) { mmqe($mmbg); }
my($mmbj) = mmsy($mmal); mmsg($mmbj);
mmqh($mma,"QUIT"); close $mma; $mailman::mmbl = 0; if($mailman::mmae) {
mmrp(); } else { mmsu('t_f_frameset.htm'); } }
if($mmb->param('DELETEMARKED')) { my($mmbg) = ''; if($mmbg = mmqi()) {
mmqe($mmbg); } my(@mmc) = $mmb->param; my($mmd) = 0;
for($mmd=0;$mmd<$#mmc;$mmd++) { my($mme) = $mmc[$mmd];; if($mme =~ /^MARK\:(.*)$/) {
mmsg(mmsy($1)); } } mmqh($mma,"QUIT"); close $mma;
$mailman::mmbl = 0; if($mailman::mmae) { mmrp(); } else {
mmsu('t_f_frameset.htm'); } } if($mmal = mmqc('MOVE')) {
my($mmbm) =  mmsx($mmb->param('FOLDERTRANSFERLIST'));
if($mmbm eq 'MAILMANSPECIALSELECT' || $mmbm eq '') { mmrp(); }
my($mmbg) = ''; if($mmbg = mmqi()) { mmqe($mmbg); }
my($mmbj) = mmsy($mmal); if(mmsj($mmbj,$mmbm)) {
mmsh($mmbj,'MOVED'); } mmqh($mma,"QUIT"); close $mma;
$mailman::mmbl = 0; if($mailman::mmae) { mmrp(); } else {
mmsu('t_f_frameset.htm'); } } if($mmb->param('MOVEMARKED')) { my($mmbm) =
mmsx($mmb->param('FOLDERTRANSFERLIST'));
if($mmbm eq 'MAILMANSPECIALSELECT' || $mmbm eq '') { mmrp(); }
my($mmbg) = ''; if($mmbg = mmqi()) { mmqe($mmbg); }
my(@mmc) = $mmb->param; my($mmd) = 0; for($mmd=0;$mmd<$#mmc;$mmd++) {
my($mme) = $mmc[$mmd];; if($mme =~ /^MARK\:(.*)$/) {
my($mmbj) = mmsy($1); if(mmsj($mmbj,$mmbm)) {
mmsh($mmbj,'MOVED'); } } } mmqh($mma,"QUIT"); close $mma;
$mailman::mmbl = 0; if($mailman::mmae) { mmrp(); } else {
mmsu('t_f_frameset.htm'); } } if($mmb->param('NEW')) {
$mmb->param('ATTACH',0); mmsl('NEW',0,0);    }
if($mmb->param('USEATTACH')) { $mmb->param('ATTACH',1); mmsm(''); }
if($mmal = mmqc('REPLY')) { my($mmbj) = mmsy($mmal);
mmsl($mmbj,0,0); } if($mmal = mmqc('REPLYALL')) {
my($mmbj) = mmsy($mmal); mmsl($mmbj,1,0); }
if($mmal = mmqc('FORWARD')) { my($mmbj) = mmsy($mmal);
mmsl($mmbj,0,1); } if($mmb->param('SEND')) { mmso(); }
if($mmb->param('HELP')) { mmsu('t_help.htm'); } if($mmb->param('VERIFY')) {
print "Content-type: text/html\n\n"; unless($mmb->param('PASSWORD') eq
$mailman::strManagementPassword) { print "Authentication Error:\n" . 
"To use management features, the supplied password\n" .
"must match the management password for this installation.\n"; exit(0); }
$mailman::mmbn = 0; print "<pre>\n"; mmtn(); print "</pre>\n"; exit(0); }
if($mmb->param('REPAIR')) { my(@mmbo) = (); print "Content-type: text/plain\n\n";
unless($mmb->param('PASSWORD') eq $mailman::strManagementPassword) { print
"Authentication Error:\n" . 
"To use management features, the supplied password\n" .
"must match the management password for this installation.\n"; exit(0); }
$mailman::mmbn = 1; print "<pre>\n"; mmtn(); print "</pre>\n"; exit(0); } }
sub mmqe { my($mmbp,$mmbq) =  @_; my($mmbr) = ''; if($mmbp eq "ALRM") {
if($mailman::bUseAlarm){ alarm(0); } $mmbp = $mailman::mmbs;
mmqh($mma,"QUIT"); close $mma; } if($mailman::mmae) {
$mmbr = 't_nf_error.htm'; } else { $mmbr = 't_f_error.htm'; } my(%mmbh);
$mmbh{'ERROR'} = $mmbp; mmsu($mmbr,\%mmbh); unless($mmbq) { exit(1); } }
sub mmqf { my($mmbt) =  @_; my($mmbr) = ''; print CGI->multipart_start();
if($mailman::mmae) { $mmbr = 't_nf_status.htm'; } else { $mmbr = 't_f_status.htm'; }
my(%mmbh); $mmbh{'STATUS'} = $mmbt; mmsu($mmbr,\%mmbh);
print CGI->multipart_end(); } sub mmqg {
print "Set-cookie: MailManAuth=;$mailman::mmad" .
"expires=Sun, 03-May-1998 16:00:00 GMT\n";
print "Set-cookie: MailManCmds=;$mailman::mmad" .
"expires=Sun, 03-May-1998 16:00:00 GMT\n";
print "Set-cookie: MailManDir=;$mailman::mmad" .
"expires=Sun, 03-May-1998 16:00:00 GMT\n";
print "Expires: Sun, 03 May 1998 16:00:00 GMT\n"; $mailman::mmo = '';
$mailman::mmah = ''; if($mailman::bKioskMode) { my($mmbu) = '';
($mailman::mmbh{'GREETING'},$mmbu) = mmst('t_login.htm',
('GREETING','KIOSKMODESCRIPT')); $mailman::mmbh{'HTMLCOMMENTBEGIN'} = '<!-- ';
$mailman::mmbh{'HTMLCOMMENTEND'} = ' -->'; $mailman::mmbh{'KIOSKMODESCRIPT'} =
mmsq($mmbu,\%mailman::mmbh);
$mailman::mmbh{'HTMLCOMMENTBEGIN'} = ''; $mailman::mmbh{'HTMLCOMMENTEND'} = ''; }
else { $mailman::mmbh{'GREETING'} =
mmss('t_login.htm','GREETING'); }

print eval(mmru($mailman::mhaa[1]));
 } sub mmqh {
my($mmbx) = "\015\012"; my($mmby, $mmbz) = @_; my($mmca) = length($mmbz . $mmbx);
syswrite($mmby,$mmbz . $mmbx,$mmca); } sub mmqi {
if($mailman::mmbl){ return; } my($mmcb); unless(defined($mailman::mmo) &&
$mailman::mmo ne '') { return("No username provided, cannot proceed."); }
unless(defined($mailman::mmq) && $mailman::mmq ne '') {
return("No password provided, cannot proceed."); }
unless(defined($mailman::strIncomingServer) && $mailman::strIncomingServer ne '')
{ return("No server provided, cannot proceed."); }
retrylogin: if($mailman::bUseAlarm) { $mailman::mmbs =
"Connection to server timed out."; $SIG{'ALRM'} = \&mmqe;
alarm($mailman::iTimeoutDurationInSeconds); } my($mmcc) = 0;
$mmcc = getprotobyname('tcp'); socket($mma,PF_INET,SOCK_STREAM,$mmcc);
my($mmcd) = 0; $mmcd = gethostbyname($mailman::strIncomingServer); unless($mmcd) {
return("Could not find an IP address for the host " .
"\"$mailman::strIncomingServer\"."); } my($mmce) = '';
$mmce = sockaddr_in(110, $mmcd); unless(connect($mma, $mmce)) {
return("Could not connect to server " .
"\"$mailman::strIncomingServer\", \"$!\""); } select($mma); $|=1; select(STDOUT);
binmode($mma); $mailman::mmbs = "The server connected, but will not respond.";
if($mailman::bUseAlarm){ alarm(180); } unless(<$mma> =~ /^\+OK/) {
return("The server does not respond appropriately."); } $mailman::mmbs =
"The server timed out during login."; if($mailman::bUseAlarm){ alarm(180); }
mmqh($mma,"USER $mailman::mmo"); my($mmcf) = ''; $mmcf = <$mma>;
unless($mmcf =~ /^\+OK/) { return($mmcf); } mmqh($mma,"PASS $mailman::mmq");
$mmcf = <$mma>; unless($mmcf =~ /^\+OK/) { if((($mmcf =~ /another session/i) ||
($mmcf =~ /another POP3 session/i) || ($mmcf =~ /mailbox in use/i) ||
($mmcf =~ /unable to lock/i) || ($mmcf =~ /mailbox busy/i)) && $mmcb < 12) {
mmqh($mma,"QUIT"); close $mma; $mmcb++; sleep(5); goto retrylogin; }
return($mmcf); } mmqh($mma,'STAT'); $mmcf = <$mma>;
$mmcf =~ /^\+OK\s+(\d+)\s+/i; $mailman::mmcg = $1; if($mailman::mmcg == 0) {
$mailman::mmbl = 1; return; } mmqh($mma,"LIST"); $mmcf = <$mma>;
unless($mmcf =~ /^\+OK/) { return($mmcf); } $mailman::mmcg = 0;
while(<$mma> =~ /(\d+) (\d+)/) { $mailman::mmch[$1] = $2; $mailman::mmcg++; }
$mailman::mmbl = 1; return; } sub mmqj { my($mmci,$mmcj) = @_;
my($mmck) = ''; if(defined($mmci) && defined($mmcj)) { $mmck .= mmsx(
$mmcj . $mailman::mmcl[$mmci]) . '|'; } else { $mmck .= mmsx(
$mailman::mmcm) . '|'; } $mmck .= mmsx($mailman::mmo) . '|';
$mmck .= mmsx($mailman::strIncomingServer) . '|';
$mmck .= mmsx($mailman::mmaz) . '|';
$mmck .= mmsx($mailman::mmcn) . '|';
$mmck .= mmsx($mailman::mmco) . '|';
$mmck .= mmsx($mailman::mmcp) . '|';
$mmck .= mmsx($mailman::mmcq) . '|';
$mmck .= mmsx($mailman::mmcr) . '|';
$mmck .= mmsx($mailman::mmcs) . '|'; if(defined($mmci)) {
$mmck .= $mailman::mmch[$mmci] . '|'; } else { $mmck .= $mailman::mmch . '|'; }
$mmck .= $mailman::mmct . '|'; $mmck .= $mailman::mmcu . '|';
$mmck .= $mailman::mmcv; return $mmck; } sub mmqk { my($mmcw) = @_;
chomp($mmcw); my(@mmcx) = split(/\|/,$mmcw); if($#mmcx < 12) { return 0; }
$mailman::mmcm =             mmsy($mmcx[0]);
$mailman::mmcy = mmsy($mmcx[1]);
$mailman::mmcz=    mmsy($mmcx[2]);
$mailman::mmaz =              mmsy($mmcx[3]);
$mailman::mmcn =              mmsy($mmcx[4]);
$mailman::mmco =            mmsy($mmcx[5]);
$mailman::mmcp =            mmsy($mmcx[6]);
$mailman::mmcq =      mmsy($mmcx[7]);
$mailman::mmcr =         mmsy($mmcx[8]);
$mailman::mmcs =         mmsy($mmcx[9]);
$mailman::mmch =                       $mmcx[10];
$mailman::mmct =                       $mmcx[11]; $mailman::mmct =~ s/\s//g; 
$mailman::mmcu =                $mmcx[12]; $mailman::mmcu =~ s/\s//g; 
$mailman::mmcv =                   $mmcx[13];
unless($mailman::mmaz){ $mailman::mmaz = "Unknown";}
unless($mailman::mmco){ $mailman::mmco = "Unknown";}
unless($mailman::mmcp){ $mailman::mmcp = "Unknown";}
unless($mailman::mmcr){ $mailman::mmcr = "Unspecified";}
$mailman::mmda = mmqv(mmqt($mailman::mmaz));
$mailman::mmdb = mmqv(mmqt($mailman::mmco));
$mailman::mmdc = mmqv(mmqt($mailman::mmcr));
$mailman::mmdd = mmqv(mmqt($mailman::mmcp)); return 1; }
sub mmql { unless(-d $mailman::strLocalLocationUsers) {
mmqe("Could not locate directory \"" .
"$mailman::strLocalLocationUsers\" for user information."); }
unless(-d $mailman::mmv) { unless(mkdir($mailman::mmv,0755)) { mmqe(
"Could not create user directory \"$mailman::mmv\" " .
"in \"$mailman::strLocalLocationUsers\".  Make sure that " .
"\"$mailman::strLocalLocationUsers\" is writable by the " . "web user."); }
if(defined($mailman::iLocalDirectoryPermissions)) {
mmtd($mailman::mmv, $mailman::iLocalDirectoryPermissions); } } }
sub mmqm { unless($mailman::mmah) { return; } my($mmde) = 
$mailman::mmv . '/' . mmsx($mailman::mmah); unless(-d $mmde) {
unless(mkdir($mmde,0755)) { mmqe("Could not create directory for folder " .
"\"$mailman::mmah\" " . "in \"$mailman::mmv\".  Make sure that " .
"\"$mailman::mmv\" is writable by the " . "web user."); }
if(defined($mailman::iLocalDirectoryPermissions)) { mmtd($mmde,,
$mailman::iLocalDirectoryPermissions); } if($mailman::mmah eq 'INBOX') {
$mailman::mmah = 'SENT'; mmqm(); $mailman::mmah = 'TRASH';
mmqm(); $mailman::mmah = 'INBOX'; } } } sub mmqn {
$mailman::mmah = 'INBOX'; mmqp();
if($mailman::bDownloadIndividualAccounts) { return; } mmrn();
my($mmdf,$mmdg,$mmdh) = ('','',''); if($mailman::mmdi) { $mmdf = $mailman::mmo;
$mmdg = $mailman::mmq; $mmdh   = $mailman::strIncomingServer; } my($mmdj) = '';
foreach $mmdj (sort keys %mailman::mmdk) { $mailman::mmo = 
$mailman::mmdk{$mmdj}->{'ACCOUNTITEM_USERNAME'}; $mailman::mmq =
$mailman::mmdk{$mmdj}->{'ACCOUNTITEM_PASSWORD'}; $mailman::strIncomingServer =
$mailman::mmdk{$mmdj}->{'ACCOUNTITEM_SERVER'}; $mailman::mmah =
$mailman::mmdk{$mmdj}->{'ACCOUNTITEM_FOLDER'}; mmqp(); }
if($mailman::mmdi) { $mailman::mmo = $mmdf; $mailman::mmq = $mmdg;
$mailman::strIncomingServer = $mmdh; $mailman::mmah = 'INBOX'; } }
sub mmqo { my($mmdl) = shift; mmrn();
my($mmdf,$mmdg,$mmdh) = ('','',''); if($mailman::mmdi) { $mmdf = $mailman::mmo;
$mmdg = $mailman::mmq; $mmdh   = $mailman::strIncomingServer; } my($mmdj) = '';
foreach $mmdj (sort keys %mailman::mmdk) { $mailman::mmo = 
$mailman::mmdk{$mmdj}->{'ACCOUNTITEM_USERNAME'}; $mailman::mmq =
$mailman::mmdk{$mmdj}->{'ACCOUNTITEM_PASSWORD'}; $mailman::strIncomingServer =
$mailman::mmdk{$mmdj}->{'ACCOUNTITEM_SERVER'}; $mailman::mmah =
$mailman::mmdk{$mmdj}->{'ACCOUNTITEM_FOLDER'}; if($mmdj =~ /$mmdl/i) {
mmqp(); } } if($mailman::mmdi) { $mailman::mmo = $mmdf;
$mailman::mmq = $mmdg; $mailman::strIncomingServer = $mmdh; } }
sub mmqp { unless(defined($mailman::mmah) && length($mailman::mmah))
{ $mailman::mmah = 'INBOX'; } my($mmbg) = ''; if($mmbg = mmqi()) {
mmqe($mmbg); } if($mailman::iUserDiskQuota) { unless($mailman::mmdm) {
mmtl(); } if($mailman::mmdm >= $mailman::iUserDiskQuota) { return; } }
mmql(); mmqm(); mmqy(); use Fcntl;
my($mmcj) = $mailman::mmo . '@' .  $mailman::strIncomingServer . '@';
if($mailman::mmcg == 0) { mmqh($mma,"QUIT"); close $mma; $mailman::mmbl = 0;
return; } mmqh($mma,"UIDL"); my($mmcf) = ''; $mmcf = <$mma>;
unless($mmcf =~ /^\+OK/) { mmqe($mmcf); } my $mmd=0;
while(<$mma> =~ /(\d+)\s+(\S+)/) { my($mmcg,$mmdn) = ($1, $2);
if(defined($mailman::mmdo) && $mailman::mmdo) {
$mmdn =~ s/(\w)/sprintf("%02x", ord($1))/eg; } $mailman::mmdp[$mmd] = $mmcg;
$mailman::mmcl[$mmcg] = $mmdn; $mailman::mmdq{$mmcj . $mmdn} = 1; $mmd++; }
my $mmdr = $mmd; my(%mmds); my($mmdt) = ''; my(%mmdu) = (); my(%mmdv) = ();
my($mmci) = my($mmdw) = 0; my($mmdx) = 0; my(%mmdy); my($mmdz) = new FileHandle();
my($mmea) = $mailman::mmv . '/INBOX/msglist'; retry: if(open($mmdz,"<$mmea")) {
flock($mmdz,2); my($mmbz) = ''; $mmbz = <$mmdz>; if($mmbz =~ /^(\d+)\s(\d+)\s/) {
$mmci = $1; } elsif($mmbz =~ /^(\d+)\s/) { $mmci = $1; } else { close($mmdz);
mmtq($mailman::mmv . '/INBOX'); goto retry; } $mmdw = 0;
while(defined($_ = <$mmdz>)) { chomp;
if(/^([^\|]+)\|/ && mmqk($_)) { my($mmeb) = mmsy($1);
$mmds{$mmeb} = 1; $mmdw++; unless(defined($mailman::mmcv) &&
$mailman::mmcv =~ /R/i) { $mmdx++; } my($mmec) = $mailman::mmcq; my($mmed) = 0;
while(defined($mmdu{$mmec})) { if($mmec =~ s/^([^\_]*)\_(\d+)/$1/) { $mmed++; }
$mmec .= "_$mmed"; } $mmdu{$mmec} = $_; } elsif(/^DELETED\:\s+(\S+)\s*$/) {
my($mmeb) = mmsy($1); if($mailman::mmdq{$mmeb} || $mmeb !~ /^$mmcj/) {
$mmds{$mmeb} = 1; $mmdy{$mmeb} = 1; $mmdt .= $_ . "\n"; } }
elsif(/^\S+\:\s+(\S+)\s*$/) { my($mmeb) = mmsy($1);
if($mailman::mmdq{$mmeb} || $mmeb !~ /^$mmcj/) { $mmds{$mmeb} = 1;
$mmdt .= $_ . "\n"; } } } if($mmdw != $mmci) { close($mmdz);
mmtq($mailman::mmv . '/INBOX'); goto retry; } close($mmdz); } my($mmee);
my($mmef) = ''; my($mmeg) = 0; my($mmeh) = 0;
message: for($mmd=0;$mmd<$mmdr;$mmd++) { $mmee = $mailman::mmdp[$mmd]; my($mmei) =
$mmcj . $mailman::mmcl[$mmee]; if($mailman::mmas) { if($mmdy{$mmei}) {
mmqh($mma,"DELE $mmee"); $mmcf = <$mma>; unless($mmcf =~ /^\+OK/) {
mmqe("While trying to delete a message " .
"that has been deleted from your message " .
"folders, your POP3 server responded " . "\"$mmcf\""); } } } unless($mmds{$mmei}) {
my($mmej) =  mmsx($mmcj . $mailman::mmcl[$mmee]);
mmqq($mmee,$mmej); if($mailman::iUserDiskQuota) { $mailman::mmdm +=
(-s "${mailman::mmv}/" . mmsx($mailman::mmah) . "/$mmej");
if($mailman::mmdm >= $mailman::iUserDiskQuota) { last message; } }
$mailman::mmcv = ''; my($mmek) = mmqj($mmee, $mmcj);
my($mmec) = mmte($mailman::mmcp); if($mailman::mmah eq 'INBOX') {
my($mmed) = 0; while(defined($mmdu{$mmec})) { if($mmec =~ s/^([^\_]*)\_(\d+)/$1/) {
$mmed++; } $mmec .= "_$mmed"; } $mmdu{$mmec} = $mmek; $mmeg++; } else {
$mmdt .= 'MOVED: ' . mmsx($mmei) . "\n"; my($mmed) = 0;
while(defined($mmdv{$mmec})) { if($mmec =~ s/^([^\_]*)\_(\d+)/$1/) { $mmed++; }
$mmec .= "_$mmed"; } $mmdv{$mmec} = $mmek; $mmeh++; } if($mailman::mmar) {
mmqh($mma, "DELE $mmee"); $mmcf = <$mma>; unless($mmcf =~ /^\+OK/) {
mmqe($mmcf); } } } } unless(open($mmdz,">$mmea")) {
mmqe("Could not create user message list in \"" .
$mmea ."\".  Make sure that the  " . "directory is writable by the web user."); }
flock($mmdz,2); $mailman::mmcg = $mmci + $mmeg;
print {$mmdz} "$mailman::mmcg $mmdx\n"; my($mmek) = '';
foreach $mmek (sort {$a <=> $b} keys %mmdu) { print {$mmdz} $mmdu{$mmek} . "\n"; }
print {$mmdz} "\n" . $mmdt; close($mmdz); if(($mailman::mmah ne 'INBOX') && $mmeh) {
mmsk(mmsx($mailman::mmah), $mmeh, \%mmdv); }
mmqh($mma,"QUIT"); close $mma; $mailman::mmbl = 0; } sub mmqq
{ my($mmee,$mmel) = @_; my($mmem) = new FileHandle(); mmqr($mmee);
$mmel =  "${mailman::mmv}/" . mmsx($mailman::mmah) . "/$mmel";
unless(open($mmem,">$mmel")) {
mmqe("Could not create file to store message " .
"in \"$mmel\".  Make sure that the " . "directory is writable by the web user.");
} my($mmen) = $mmee; mmqh($mma,"RETR $mmen"); my($mmcf) = '';
$mmcf = <$mma>; unless($mmcf =~ /^\+OK/) { mmqe($mmcf); } my($mmbz) = '';
while(defined($mmbz = <$mma>)) { if($mmbz =~ /^\.\r$/){ last; }
print {$mmem} $mmbz; } close $mmem; if(defined($mailman::iLocalFilePermissions)) {
mmtd($mmel,$mailman::iLocalFilePermissions); } }
sub mmqr { my($mmci) =  @_; $mailman::mmbs =
"The server timed out fetching a header."; if($mailman::bUseAlarm){ alarm(10); }
mmqh($mma,"TOP $mmci 0"); my($mmcf) = ''; $mmcf = <$mma>;
unless($mmcf =~ /^\+OK/) { mmqe($mmcf); } mmqs($mma);
$mailman::mmeo = $mmci . 'H' . $mailman::mmep; $mailman::mmeq = $mmci; }
sub mmqs { my($mmby) = shift; $mailman::mmaz = ''; $mailman::mmcn = '';
$mailman::mmco = ''; $mailman::mmcp = ''; $mailman::mmcq = '0';
$mailman::mmcr = ''; $mailman::mmcs = ''; $mailman::mmep = ''; $mailman::mmct = 0;
$mailman::mmcu = 0; my($mmer) = 0; my($mmes) = 0; my($mmet) = 0; my($mmeu) = 1;
my($mmev) = ''; my($mmew) = -1; while(defined($_ = <$mmby>)) {
if(/^[\r\n]+$/){ $mmer = 1; } if(/^\.[\r\n]*$/){ last; }
if(/^Content-type\:\s+([^\;\s]+)[\;\s]/i) { my($mmex) = $1; if(
($mmex !~ /multipart\/alternative/i) && ($mmex !~ /text\//i)) { $mailman::mmcu = 1;
} } if(/^begin \d\d\d (\S+)\s*$/i) { $mailman::mmcu = 1; } unless($mmer) {
$mmew = mmte($_); if($mmew != -1) { $mailman::mmcq = $mmew; } $mmeu = 1;
if(/^To\: (.+)$/i || ((/^\s(.+)$/) && $mmes)) { $mailman::mmaz .= $1;
$mailman::mmaz =~ s/^(.*)[\r\n]+$/$1/;
$mailman::mmaz = mmqt($mailman::mmaz); $mmev .= $_; $mmes = 1; $mmet = 0;
$mmeu = 0; } if(/^CC\: (.+)$/i || ((/^\s(.+)$/) && $mmet)) { $mailman::mmcn .= $1;
$mailman::mmcn =~ s/^(.*)[\r\n]+$/$1/;
$mailman::mmcn = mmqt($mailman::mmcn); $mmev .= $_; $mmes = 0; $mmet = 1;
$mmeu = 0; } if(/^From\: (.+)$/i) { $mailman::mmco = $1;
$mailman::mmco =~ s/^(.*)[\r\n]+$/$1/;
$mailman::mmco = mmqt($mailman::mmco); $mmev .= $_; }
if(/^Date\: (.+)$/i) { $mailman::mmcp = $1; $mailman::mmcp =~ s/^(.*)[\r\n]+$/$1/;
$mmev .= $_; } if(/^Subject\: (.+)$/i) { $mailman::mmcr = $1;
$mailman::mmcr =~ s/^(.*)[\r\n]+$/$1/;
$mailman::mmcr = mmqt($mailman::mmcr); $mmev .= $_; }
if(/^Reply-To\: (.+)$/i) { $mailman::mmcs = $1;
$mailman::mmcs =~ s/^(.*)[\r\n]+$/$1/; $mmev .= $_; } if(/^Message-ID\: (.+)$/i) {
$mailman::mmep = $1; $mailman::mmep =~ s/^(.*)[\r\n]+$/$1/; }        if($mmeu) {
$mmes = 0; $mmet = 0; } } if(/^MIME-Version\: 1\.0/i) { if(!$mmer) { $mailman::mmct = 1;
} } } if($mailman::mmep eq "") { $mailman::mmep = $mmev;
while(length($mailman::mmep)>20) {
$mailman::mmep = (substr($mailman::mmep,0,20) ^  substr($mailman::mmep,20)); }
$mailman::mmep = pack("u*",$mailman::mmep); }
$mailman::mmep =~ s/(\W)/sprintf("%%%x", ord($1))/eg;
unless($mailman::mmaz){ $mailman::mmaz = "Unknown";}
unless($mailman::mmco){ $mailman::mmco = "Unknown";}
unless($mailman::mmcp){ $mailman::mmcp = "Unknown";}
unless($mailman::mmcr){ $mailman::mmcr = "Unspecified";}
unless($mailman::mmeo){ $mailman::mmeo = "0";}
$mailman::mmda = mmqv($mailman::mmaz);
$mailman::mmdb = mmqv($mailman::mmco);
$mailman::mmey = mmqv($mailman::mmcn);
$mailman::mmdc = mmqv($mailman::mmcr);
$mailman::mmdd = mmqv($mailman::mmcp); } sub mmqt { my $mmez = shift;
$mmez =~ s/\=\?iso-8859-1\?q\?([^\?]+)\?\=/
mmry(mmrx($1))/xeig; $mmez =~
s/\=\?iso-8859-1\?b\?([^\?]+)\?\=/ mmrz(mmrx($1))/xeig;
return $mmez; } sub mmqu { my($mmbj) = @_; $mmbj =~ /^(\d+)H(.+)$/;
my($mmfa) = $1; my($mmfb) = $2; if($1 eq '' || $2 eq '') {
mmqe('The message ID string "' . $mmbj .  '" is badly formed.'); }
$mmfb =~ s/%(..)/pack("c",hex($1))/ge; $mailman::mmbs =
"The server timed out during message listing.";
if($mailman::bUseAlarm){ alarm(180); } mmqh($mma,"LIST"); my($mmcf) = '';
$mmcf = <$mma>; unless($mmcf =~ /^\+OK/) { mmqe($mmcf); } $mailman::mmfc = 0;
while(<$mma> =~ /(\d+) (\d+)/) { $mailman::mmch[$1] = $2; $mailman::mmfc++; }
my($mmd) = $mmfa; my($mmfd) = 0; while($mmd>0) { mmqr($mmd);
$mailman::mmep =~ s/%(..)/pack("c",hex($1))/ge; if($mailman::mmep eq  $mmfb) {
$mmfd = 1; last; } $mmd--; } if(!$mmfd) { $mailman::mmaz = ''; $mmd = $mmfa;
mmqr($mmd); } if($mailman::mmaz eq '') {
mmqe('Could not find the specified message.'); } return ($mmd); } sub mmqv
{ my($mmfe) = @_; $mmfe =~ s/\&/\&amp\;/g; $mmfe =~ s/\</\&lt\;/g;
$mmfe =~ s/\>/\&gt\;/g; $mmfe =~ s/\%mmff/\</g; $mmfe =~ s/\%mmfg/\>/g;
my($mmfh) = '(http://|https://|ftp://)' .
q%(?:&(?![gl]t;)|[^\s\(\)\|<>,"'\&])+% . q%[^\.?!;,"'\|\[\]\(\)\s<>\&]%;
my($mmfi) = "\<a target=\"_top\" href\=\"$mailman::mmab?BACKGROUND="; $mmfe =~
s/($mmfh)/$mmfi.mmsx($1)."\"\>$1\<\/a\>"/eig; if($mailman::mmae) {
$mmfe =~ s/(href\=\"[^\"]*)(BACKGROUND\=)/${1}NOFRAMES\=TRUE&$2/g; } return $mmfe;
} sub mmqw { mmqi();
$mailman::mmbh{'USERNAME'} = $mailman::mmo;
$mailman::mmbh{'USERNAMEHIDDEN'} = $mailman::mmp;
$mailman::mmbh{'SERVERHIDDEN'} = $mailman::mms;
$mailman::mmbh{'PASSWORDHIDDEN'} = $mailman::mmr;
$mailman::mmbh{'CHECKSUM'} = $mailman::mmaa;
if(defined($mailman::strFromDomainName)) { $mailman::mmbh{'SERVER'} =
mmtu($mailman::strFromDomainName); } else { $mailman::mmbh{'SERVER'} =
mmtu($mailman::strIncomingServer); } my($mmfj, $mmfk, $mmfl) =
mmst('t_folders.htm',
('FOLDER_EVEN','FOLDER_ODD','DELETEFOLDERIMAGE'));
$mailman::mmbh{'AUTHENTICATION'} = 'MailManEscape(AUTHENTICATION)';
$mailman::mmbh{'SETTINGS'} = 'MailManEscape(SETTINGS)';
my(@mmfm) = mmti(); my($mmfn) = 0; my($mmfo); foreach $mmfo (@mmfm) {
my($mmfp,$mmfq) = mmtj($mmfo);
$mailman::mmbh{'FOLDERNAME'} = mmqv($mmfo);
$mailman::mmbh{'FOLDERNAMESAFE'} = mmsx($mmfo);
$mailman::mmbh{'FOLDERNAMESAFESAFE'} =
mmsx($mailman::mmbh{'FOLDERNAMESAFE'});
$mailman::mmbh{'NUMMESSAGES'} = $mmfp;
$mailman::mmbh{'NUMUNREADMESSAGES'} = $mmfq; if($mmfp == 0 &&
$mmfo !~ /^INBOX$/i && $mmfo !~ /^SENT$/i && $mmfo !~ /^TRASH$/i) {
$mailman::mmbh{'DELETEFOLDERIMAGE'} = mmsq($mmfl,
\%mailman::mmbh); } else { $mailman::mmbh{'DELETEFOLDERIMAGE'} = ''; } my($mmfr) = '';
if(($mmfn+1)%2==0) { $mmfr = mmsq($mmfj, \%mailman::mmbh); } else {
$mmfr = mmsq($mmfk, \%mailman::mmbh); } $mmfn++;
$mailman::mmbh{'FOLDERS'} .= $mmfr; }
$mailman::mmbh{'FOLDERS'} =~ s/MailManEscape\(/MailMan\(/gi;
mmsu('t_folders.htm',\%mailman::mmbh); } sub mmqx {
mmqi(); $mailman::mmbh{'USERNAME'} = $mailman::mmo;
$mailman::mmbh{'USERNAMEHIDDEN'} = $mailman::mmp;
$mailman::mmbh{'SERVERHIDDEN'} = $mailman::mms;
$mailman::mmbh{'PASSWORDHIDDEN'} = $mailman::mmr;
$mailman::mmbh{'CHECKSUM'} = $mailman::mmaa; mmqy();
$mailman::mmbh{'PREF_REALNAME'} = $mailman::mmam;
$mailman::mmbh{'PREF_EMAIL'} = $mailman::mman;
$mailman::mmbh{'PREF_OUTGOING'} = $mailman::mmap;
$mailman::mmbh{'PREF_SIGNATURE'} = $mailman::mmao;
$mailman::mmbh{'PREF_NUMPERPAGE'} = $mailman::mmaq; if($mailman::mmar) {
$mailman::mmbh{'PREF_DELETEDOWNLOAD'} = 'checked'; } else {
$mailman::mmbh{'PREF_DELETEDOWNLOAD'} = ''; } if($mailman::mmas) {
$mailman::mmbh{'PREF_DELETEPROXY'} = 'checked'; } else {
$mailman::mmbh{'PREF_DELETEPROXY'} = ''; } if($mailman::mmat) {
$mailman::mmbh{'PREF_DELETESAVE'} = 'checked'; } else {
$mailman::mmbh{'PREF_DELETESAVE'} = ''; } if($mailman::mmau) {
$mailman::mmbh{'PREF_SENDSAVE'} = 'checked'; } else {
$mailman::mmbh{'PREF_SENDSAVE'} = ''; }
$mailman::mmbh{'PREF_STARTUP_'.$mailman::mmav} = 'checked';
if(defined($mailman::strFromDomainName)) {
$mailman::mmbh{'SERVER'} = $mailman::strFromDomainName; } else {
$mailman::mmbh{'SERVER'} = $mailman::strIncomingServer; }
mmsu('t_preferences.htm',\%mailman::mmbh); } sub mmqy {
my($mmfs) = new FileHandle(); $mailman::mmft = "${mailman::mmv}/preferences";
if(!open($mmfs,"<$mailman::mmft")) { $mailman::mmam = '';
if(defined($mailman::strFromDomainName)) { $mailman::mman = 
$mailman::mmo . '@' . $mailman::strFromDomainName; } else { $mailman::mman =
$mailman::mmo . '@' . $mailman::strIncomingServer; } $mailman::mmao = '';
$mailman::mmar = 0; $mailman::mmas = 0; $mailman::mmat = 1; $mailman::mmau = 1;
$mailman::mmaq = $mailman::iMessagesPerPage; $mailman::mmap = '';
$mailman::mmav = 'INBOX'; return; } flock($mmfs,2); my($mmbz) = '';
while(defined($mmbz = <$mmfs>)) { if($mmbz =~ /REALNAME\:\s+\"([^\"]*)\"/) {
$mailman::mmam = mmsy($1); } elsif($mmbz =~ /EMAIL\:\s+\"([^\"]*)\"/) {
$mailman::mman = mmsy($1); }
elsif($mmbz =~ /OUTGOING\:\s+\"([^\"]*)\"/) {
$mailman::mmap = mmsy($1); }
elsif($mmbz =~ /SIGNATURE\:\s+\"([^\"]*)\"/) {
$mailman::mmao = mmsy($1); } elsif($mmbz =~ /STARTUP\:\s+\"([^\"]*)\"/)
{ $mailman::mmav = mmsy($1); }
elsif($mmbz =~ /DELETEDOWNLOAD\:\s+\"([^\"]*)\"/) { if($1 eq '1') {
$mailman::mmar = 1; } else { $mailman::mmar = 0; } }
elsif($mmbz =~ /DELETEPROXY\:\s+\"([^\"]*)\"/) { if($1 eq '1') { $mailman::mmas = 1;
} else { $mailman::mmas = 0; } } elsif($mmbz =~ /DELETESAVE\:\s+\"([^\"]*)\"/) {
if($1 eq '1') { $mailman::mmat = 1; } else { $mailman::mmat = 0; } }
elsif($mmbz =~ /SAVESAVE\:\s+\"([^\"]*)\"/) { if($1 eq '1') { $mailman::mmau = 1; }
else { $mailman::mmau = 0; } } elsif($mmbz =~ /NUMPERPAGE\:\s+\"([^\"]*)\"/) {
$mailman::mmaq = $1; } } close($mmfs); } sub mmqz {
my($mmfs) = new FileHandle(); my($mmfu) = $mailman::mmae; $mailman::mmae = 1;
mmql(); $mailman::mmft = "${mailman::mmv}/preferences";
if(!open($mmfs,">$mailman::mmft")) {
mmqe("Could not open the preferences file \"" . $mailman::mmft .
"\" for storing this user's preferences.  "); } flock($mmfs,2); print {$mmfs}
"REALNAME: \"" . mmsx($mailman::mmam) . "\"\n"; print {$mmfs}
"EMAIL: \"" . mmsx($mailman::mman) . "\"\n"; print {$mmfs}
"OUTGOING: \"" . mmsx($mailman::mmap) . "\"\n"; print {$mmfs}
"STARTUP: \"" . mmsx($mailman::mmav) . "\"\n"; print {$mmfs}
"DELETEDOWNLOAD: \"" . $mailman::mmar . "\"\n"; print {$mmfs}
"DELETEPROXY: \"" . $mailman::mmas . "\"\n"; print {$mmfs}
"DELETESAVE: \"" . $mailman::mmat . "\"\n"; print {$mmfs}
"SAVESAVE: \"" . $mailman::mmau . "\"\n"; print {$mmfs}
"NUMPERPAGE: \"" . $mailman::mmaq . "\"\n"; print {$mmfs} "SIGNATURE: \"" .
mmsx($mailman::mmao) . "\"\n"; close($mmfs); $mailman::mmae = $mmfu; }
sub mmra { my($mmbr) = 't_addresses.htm';
$mailman::mmbh{'USERNAME'} = $mailman::mmo;
$mailman::mmbh{'USERNAMEHIDDEN'} = $mailman::mmp;
$mailman::mmbh{'SERVERHIDDEN'} = $mailman::mms;
$mailman::mmbh{'PASSWORDHIDDEN'} = $mailman::mmr;
$mailman::mmbh{'CHECKSUM'} = $mailman::mmaa;
if(defined($mailman::strFromDomainName)) {
$mailman::mmbh{'SERVER'} = $mailman::strFromDomainName; } else {
$mailman::mmbh{'SERVER'} = $mailman::strIncomingServer; }
mmrb(); if($mailman::mmfv) { my($mmfw, $mmfx) =
mmst($mmbr, ('INDIVIDUAL_EVEN','INDIVIDUAL_ODD'));
my($mmfy) = 0; my($mmba) = ''; foreach $mmba (sort keys %mailman::mmbb) {
$mailman::mmbh{'NICKNAME'} = $mmba;
$mailman::mmbh{'NICKNAMESAFE'} = mmsx($mmba); my($mmbc) =
$mailman::mmbb{$mmba}->{'FIRSTNAME'}; my($mmbd) =
$mailman::mmbb{$mmba}->{'LASTNAME'}; my($mmbe) =
$mailman::mmbb{$mmba}->{'ADDRESS'}; if(($mmbc ne '') || ($mmbd ne '')) {
$mailman::mmbh{'ADDRESS'} = "$mmbc $mmbd " . "&lt;$mmbe&gt;"; } else {
$mailman::mmbh{'ADDRESS'} = "$mmbe"; } if($mmfy%2==0) {
$mailman::mmbh{INDIVIDUALS} .= mmsq($mmfw,\%mailman::mmbh); } else {
$mailman::mmbh{INDIVIDUALS} .= mmsq($mmfx,\%mailman::mmbh); }
$mmfy++; } } else { $mailman::mmbh{'INDIVIDUALS'} = mmss($mmbr,
'NOBODY_INDIVIDUAL'); } mmrc(); if($mailman::mmfz) {
my($mmga, $mmgb) = mmst($mmbr, ('GROUP_EVEN','GROUP_ODD'));
my($mmfy) = 0; my($mmba) = ''; foreach $mmba (sort keys %mailman::mmbf) {
$mailman::mmbh{'NICKNAME'} = $mmba;
$mailman::mmbh{'NICKNAMESAFE'} = mmsx($mmba);
$mailman::mmbh{'ADDRESSES'} = $mailman::mmbf{$mmba};
$mailman::mmbh{'ADDRESSES'} =~ s/(\r\n)|(\r\n)/,\ /g; 
$mailman::mmbh{'ADDRESSES'} =~ s/[\r\n]/,\ /g;        
$mailman::mmbh{'ADDRESSES'} =~ s/\,\ $//g; if($mmfy%2==0) {
$mailman::mmbh{GROUPS} .= mmsq($mmga,\%mailman::mmbh); } else {
$mailman::mmbh{GROUPS} .= mmsq($mmgb,\%mailman::mmbh); } $mmfy++; } }
else { $mailman::mmbh{'GROUPS'} = mmss($mmbr, 'NOBODY_GROUP');
} mmsu($mmbr,\%mailman::mmbh); } sub mmrb {
my($mmgc) = new FileHandle(); mmql(); my($mmgd) =
"${mailman::mmv}/individuals"; if(!open($mmgc,"<$mmgd")) { return; } flock($mmgc,2);
my($mmba) = ''; my($mmge) = ''; $mailman::mmfv = 0; while(defined($_ = <$mmgc>)) {
if(/^BEGIN\s+(\S+)\s*/) { $mmba = mmsy($1); $mmge = $mmba;
$mmge =~ tr/[A-Z]/[a-z]/; $mailman::mmfv++; $mailman::mmbb{$mmge}->{NICKNAME} =
$mmba; } elsif(/^(\S+)\s+(\S+)\s*$/) { $mailman::mmbb{$mmge}->{$1} =
mmsy($2); } } close($mmgc); } sub mmrc {
my($mmgc) = new FileHandle(); mmql();
my($mmgf) = "${mailman::mmv}/groups"; if(!open($mmgc,"<$mmgf")) { return; }
flock($mmgc,2); my($mmba) = ''; my($mmge) = ''; $mailman::mmfz = 0;
while(defined($_ = <$mmgc>)) { if(/^(\S+)\s+\"(\S+)\"\s*/) {
$mmba = mmsy($1); $mmge = $mmba; $mmge =~ tr/[A-Z]/[a-z]/;
$mailman::mmbf{$mmge} .= mmsy($2); $mailman::mmfz++; } } close($mmgc); }
sub mmrd { my($mmbg) = shift;
my($mmgc) = new FileHandle(); my($mmbr) = 't_addressesindividual.htm';
$mailman::mmbh{'USERNAME'} = $mailman::mmo;
$mailman::mmbh{'USERNAMEHIDDEN'} = $mailman::mmp;
$mailman::mmbh{'SERVERHIDDEN'} = $mailman::mms;
$mailman::mmbh{'PASSWORDHIDDEN'} = $mailman::mmr;
$mailman::mmbh{'CHECKSUM'} = $mailman::mmaa;
if(defined($mailman::strFromDomainName)) {
$mailman::mmbh{'SERVER'} = $mailman::strFromDomainName; } else {
$mailman::mmbh{'SERVER'} = $mailman::strIncomingServer; } my($mmba) = '';
if($mmb->param('ADDRESSINDIVIDUAL')) { $mmba = $mmb->param('ADDRESSINDIVIDUAL');
$mailman::mmbh{'NICKNAME'} = $mmba;
$mailman::mmbh{'NICKNAME'} = mmsq(
mmss($mmbr, 'NICKNAME_FIXED'),\%mailman::mmbh);
mmql(); my($mmgd) = "${mailman::mmv}/individuals";
if(!open($mmgc,"<$mmgd")) { mmqe("Could not open the address file \"" .
$mmgd . "\" for storing this user's addresses.  "); } flock($mmgc,2); my($mmgg) = 0;
my($mmgh) = 0; my($mmgi) = ''; individualsline: while(defined($_ = <$mmgc>)) {
if(/^BEGIN\s+(\S+)\s*/) { $mmgi = mmsy($1); if($mmgi =~ /$mmba/i) {
$mmgg = 1; $mmgh = 1; } } elsif(/^END/) { if($mmgh) { close($mmgc); last individualsline;
} } elsif($mmgh && /^(\S+)\s+(\S+)\s*$/) { $mailman::mmbh{"ADDRESSITEM_$1"} =
mmsy($2); } } close($mmgc); } else { $mailman::mmbh{'NICKNAME'} =
mmss($mmbr, 'NICKNAME_NEW'); } if($mmbg ne '') {
$mailman::mmbh{'ERROR'} = $mmbg; } my(@mmc) = $mmb->param; my($mmd) = 0;
for($mmd=0;$mmd<$#mmc;$mmd++) { my($mme) = $mmc[$mmd];;
if($mme =~ /^ADDRESSITEM_(.*)$/) { $mailman::mmbh{$mme} = $mmb->param($mme); } }
mmsu($mmbr,\%mailman::mmbh); } sub mmre {
my($mmbg) = shift; my($mmgc) = new FileHandle();
my($mmbr) = 't_addressesgroup.htm'; $mailman::mmbh{'USERNAME'} = $mailman::mmo;
$mailman::mmbh{'USERNAMEHIDDEN'} = $mailman::mmp;
$mailman::mmbh{'SERVERHIDDEN'} = $mailman::mms;
$mailman::mmbh{'PASSWORDHIDDEN'} = $mailman::mmr;
$mailman::mmbh{'CHECKSUM'} = $mailman::mmaa;
if(defined($mailman::strFromDomainName)) {
$mailman::mmbh{'SERVER'} = $mailman::strFromDomainName; } else {
$mailman::mmbh{'SERVER'} = $mailman::strIncomingServer; } my($mmba) = '';
if($mmb->param('ADDRESSGROUP')) { $mmba = $mmb->param('ADDRESSGROUP');
$mailman::mmbh{'NICKNAME'} = $mmba;
$mailman::mmbh{'NICKNAME'} = mmsq(
mmss($mmbr, 'NICKNAME_FIXED'),\%mailman::mmbh);
mmql(); my($mmgf) = "${mailman::mmv}/groups"; if(!open($mmgc,"<$mmgf")) {
mmqe("Could not open the address file \"" . $mmgf .
"\" for storing this user's addresses.  "); } flock($mmgc,2); my($mmgj) = '';
groupsline: while(defined($_ = <$mmgc>)) { if(/^(\S+)\s+\"(\S+)\"\s*/) {
$mmgj = mmsy($1); my $mmgk = $2; if($mmgj =~ /$mmba/i) {
$mailman::mmbh{'ADDRESSITEM_ADDRESSES'} = mmsy($mmgk); } } } close($mmgc);
} else { $mailman::mmbh{'NICKNAME'} = mmss($mmbr,
'NICKNAME_NEW'); } if($mmbg ne '') { $mailman::mmbh{'ERROR'} = $mmbg; }
my(@mmc) = $mmb->param; my($mmd) = 0; for($mmd=0;$mmd<$#mmc;$mmd++) {
my($mme) = $mmc[$mmd];; if($mme =~ /^ADDRESSITEM_(.*)$/) {
$mailman::mmbh{$mme} = $mmb->param($mme); } }
mmsu($mmbr,\%mailman::mmbh); } sub mmrf {
my($mmba) = shift; my($mmgc) = new FileHandle(); my($mmgl) = new FileHandle();
my($mmfu) = $mailman::mmae; $mailman::mmae = 1; mmql(); my($mmgd) =
"${mailman::mmv}/individuals"; if((!open($mmgc,"<$mmgd")) ||
(!open($mmgl,">$mmgd.tmp"))) { return; } flock($mmgc,2); my($mmgg) = 0; my($mmgh) = 0;
my($mmgi) = ''; while(defined($_ = <$mmgc>)) { if(/^BEGIN\s+(\S+)\s*/) {
$mmgi = mmsy($1); if($mmgi =~ /$mmba/i) { $mmgg = 1; $mmgh = 1; } else {
print {$mmgl} $_; } } elsif(/^END/) { unless($mmgh) { print {$mmgl} $_; } $mmgh = 0; }
elsif(!$mmgh) { print {$mmgl} $_; } } close($mmgc); close($mmgl); use File::Copy;
copy("$mmgd.tmp", $mmgd); $mailman::mmae = $mmfu; } sub mmrg {
my($mmba) = shift; my($mmgc) = new FileHandle(); my($mmgl) = new FileHandle();
my($mmfu) = $mailman::mmae; $mailman::mmae = 1; mmql(); my($mmgf) =
"${mailman::mmv}/groups"; if((!open($mmgc,"<$mmgf")) ||
(!open($mmgl,">$mmgf.tmp"))) { return; } flock($mmgc,2); my($mmgj) = '';
while(defined($_ = <$mmgc>)) { if(/^(\S+)\s+\"(\S+)\"\s*/) {
$mmgj = mmsy($1); unless($mmgj =~ /$mmba/i) { print {$mmgl} $_; } } else {
print {$mmgl} $_; } } close($mmgc); close($mmgl); use File::Copy; copy("$mmgf.tmp",
$mmgf); $mailman::mmae = $mmfu; } sub mmrh {
my($mmfu) = $mailman::mmae; $mailman::mmae = 1; my($mmgc) = new FileHandle();
my($mmgl) = new FileHandle(); mmql(); my($mmgm) = ''; my($mmgn) = '';
my(@mmc) = $mmb->param; my($mmd) = 0; for($mmd=0;$mmd<$#mmc;$mmd++) {
my($mme) = $mmc[$mmd];; if($mme =~ /^ADDRESSITEM_(.*)$/) { my($mmgo) = $1;
if($mmgo eq 'NICKNAME') { $mmgm = $mmb->param($mme); } else { $mmgn .= "$mmgo " .
mmsx($mmb->param($mme)) . "\n"; } } } if($mmgm eq '') {
mmrd("Error: The nickname field is " . "required."); }
if($mmb->param('ADDRESSITEM_ADDRESS') eq '') {
mmrd("Error: The address field is " . "required."); }
my($mmgd) = "${mailman::mmv}/individuals"; if((!open($mmgc,"<$mmgd")) ||
(!open($mmgl,">$mmgd.tmp"))) { if(!open($mmgc,">$mmgd")) {
mmqe("Could not open the address file \"" . $mmgd .
"\" for storing this user's addresses.  "); } print {$mmgc} "BEGIN " .
mmsx($mmgm) . "\n"; print {$mmgc} $mmgn; print {$mmgc} "END\n";
close($mmgc); $mailman::mmae = $mmfu; return; } flock($mmgc,2); my($mmgg) = 0;
my($mmgh) = 0; my($mmgi) = ''; while(defined($_ = <$mmgc>)) {
if(/^BEGIN\s+(\S+)\s*/) { $mmgi = mmsy($1); print {$mmgl} $_;
if($mmgi eq $mmgm) { $mmgg = 1; $mmgh = 1; print {$mmgl} $mmgn; } } elsif(/^END/) {
$mmgh = 0; print {$mmgl} $_; } elsif(!$mmgh) { print {$mmgl} $_; } } unless($mmgg) {
print {$mmgl} "BEGIN " . mmsx($mmgm) . "\n"; print {$mmgl} $mmgn;
print {$mmgl} "END\n"; } close($mmgc); close($mmgl); use File::Copy;
copy("$mmgd.tmp", $mmgd); $mailman::mmae = $mmfu; } sub mmri {
my($mmfu) = $mailman::mmae; $mailman::mmae = 1; my($mmgc) = new FileHandle();
my($mmgl) = new FileHandle(); mmql(); my($mmgm) =
$mmb->param('ADDRESSITEM_NICKNAME'); my($mmgp) =
mmsx($mmb->param('ADDRESSITEM_NICKNAME')); my($mmgq) = 
mmsx($mmb->param('ADDRESSITEM_ADDRESSES')); if($mmgm eq '') {
mmre("Error: The nickname field is " . "required."); }
if($mmb->param('ADDRESSITEM_ADDRESSES') eq '') {
mmre("Error: The address field is " . "required."); }
my($mmgf) = "${mailman::mmv}/groups"; if((!open($mmgc,"<$mmgf")) ||
(!open($mmgl,">$mmgf.tmp"))) { if(!open($mmgc,">$mmgf")) {
mmqe("Could not open the address file \"" . $mmgf .
"\" for storing this user's addresses.  "); } print {$mmgc} "$mmgp \"$mmgq\"\n";
close($mmgc); $mailman::mmae = $mmfu; return; } flock($mmgc,2); my($mmgr) = 0;
my($mmgj) = ''; while(defined($_ = <$mmgc>)) { if(/^(\S+)\s+\"(\S+)\"\s*/) {
$mmgj = mmsy($1); if($mmgj eq $mmgm) { $mmgr = 1; print {$mmgl}
"$mmgp \"$mmgq\"\n"; } else { print {$mmgl} $_; } } } unless($mmgr) { print {$mmgl}
"$mmgp \"$mmgq\"\n"; } close($mmgc); close($mmgl); use File::Copy; copy("$mmgf.tmp",
$mmgf); $mailman::mmae = $mmfu; } sub mmrj {
my($mmbr) = 't_accounts.htm'; $mailman::mmbh{'USERNAME'} = $mailman::mmo;
$mailman::mmbh{'USERNAMEHIDDEN'} = $mailman::mmp;
$mailman::mmbh{'SERVERHIDDEN'} = $mailman::mms;
$mailman::mmbh{'PASSWORDHIDDEN'} = $mailman::mmr;
$mailman::mmbh{'CHECKSUM'} = $mailman::mmaa;
if(defined($mailman::strFromDomainName)) {
$mailman::mmbh{'SERVER'} = $mailman::strFromDomainName; } else {
$mailman::mmbh{'SERVER'} = $mailman::strIncomingServer; } mmrn();
if($mailman::mmdi) { my($mmgs, $mmgt) = mmst($mmbr,
('ACCOUNT_EVEN','ACCOUNT_ODD')); my($mmfy) = 0; my($mmdj) = '';
foreach $mmdj (sort keys %mailman::mmdk) { my($mmcy) =
$mailman::mmdk{$mmdj}->{'ACCOUNTITEM_USERNAME'}; my($mmcz) =
$mailman::mmdk{$mmdj}->{'ACCOUNTITEM_SERVER'};
$mailman::mmbh{'ACCOUNTITEM_ID'} = mmsx($mmdj);
$mailman::mmbh{'ACCOUNTITEM_USERNAME'} = $mmcy;
$mailman::mmbh{'ACCOUNTITEM_SERVER'} = $mmcz; if($mmfy%2==0) {
$mailman::mmbh{ACCOUNTS} .= mmsq($mmgs,\%mailman::mmbh); } else {
$mailman::mmbh{ACCOUNTS} .= mmsq($mmgt,\%mailman::mmbh); } $mmfy++;
} } else { $mailman::mmbh{'ACCOUNTS'} = mmss($mmbr,
'NO_ACCOUNTS'); } mmsu($mmbr,\%mailman::mmbh); } sub mmrk {
my($mmbg) = shift; my($mmgu) = new FileHandle(); my($mmbr) = 't_account.htm';
$mailman::mmbh{'USERNAME'} = $mailman::mmo;
$mailman::mmbh{'USERNAMEHIDDEN'} = $mailman::mmp;
$mailman::mmbh{'SERVERHIDDEN'} = $mailman::mms;
$mailman::mmbh{'PASSWORDHIDDEN'} = $mailman::mmr;
$mailman::mmbh{'CHECKSUM'} = $mailman::mmaa;
if(defined($mailman::strFromDomainName)) {
$mailman::mmbh{'SERVER'} = $mailman::strFromDomainName; } else {
$mailman::mmbh{'SERVER'} = $mailman::strIncomingServer; } my($mmdj) = '';
if($mmb->param('ACCOUNT')) { $mmdj = $mmb->param('ACCOUNT'); mmql();
my($mmgv) = "${mailman::mmv}/accounts"; if(!open($mmgu,"<$mmgv")) {
mmqe("Could not open the accounts file \"" . $mmgv .
"\" for storing this user's accounts."); } flock($mmgu,2); my($mmgw) = 0;
my($mmgx) = 0; my($mmgy) = ''; accountline: while(defined($_ = <$mmgu>)) {
if(/^BEGIN\s+(\S+)\s*/) { $mmgy = $1; if($mmgy eq $mmdj) { $mmgw = 1; $mmgx = 1; } }
elsif(/^END/) { if($mmgx) { close($mmgu); last accountline; } }
elsif($mmgx && /^(\S+)\s+(\S+)\s*$/) { $mailman::mmbh{$1} = mmsy($2); } }
close($mmgu); } if($mmbg ne '') { $mailman::mmbh{'ERROR'} = $mmbg; }
if($mailman::mmbh{'ACCOUNTITEM_FOLDER'}) { $mailman::mmbh{'FOLDERDEPOSITLIST'} =
mmtk($mailman::mmbh{'ACCOUNTITEM_FOLDER'}); } else {
$mailman::mmbh{'FOLDERDEPOSITLIST'} = mmtk('INBOX'); }
my(@mmc) = $mmb->param; my($mmd) = 0; for($mmd=0;$mmd<$#mmc;$mmd++) {
my($mme) = $mmc[$mmd];; if($mme =~ /^ACCOUNTITEM_(.*)$/) {
$mailman::mmbh{$mme} = $mmb->param($mme); } }
mmsu($mmbr,\%mailman::mmbh); } sub mmrl { my($mmo) = $mailman::mmo;
my($mmq) = $mailman::mmq; my($strIncomingServer) = $mailman::strIncomingServer;
$mailman::mmbh{'ACCOUNTITEM_FOLDER'} =  $mmb->param('ACCOUNTITEM_FOLDER');
if($mmb->param('ACCOUNTITEM_USERNAME') eq '') {
mmrk("Error: The username field is " . "required."); }
if($mmb->param('ACCOUNTITEM_PASSWORD') eq '') {
mmrk("Error: The password field is " . "required."); }
if($mmb->param('ACCOUNTITEM_SERVER') eq '') {
mmrk("Error: The server field is " . "required."); } $mailman::mmo = 
$mmb->param('ACCOUNTITEM_USERNAME'); $mailman::mmq =
$mmb->param('ACCOUNTITEM_PASSWORD'); $mailman::strIncomingServer =
$mmb->param('ACCOUNTITEM_SERVER'); my($mmbg) = ''; if($mmbg = mmqi()) {
$mailman::mmo = $mmo; $mailman::mmq = $mmq;
$mailman::strIncomingServer = $strIncomingServer; $mmbg =~ s/^\-ERR//i;
mmrk('ERROR: ' . $mmbg); } else { mmqh($mma,"QUIT"); close $mma;
$mailman::mmbl = 0; $mailman::mmo = $mmo; $mailman::mmq = $mmq;
$mailman::strIncomingServer = $strIncomingServer; } my($mmfu) = $mailman::mmae;
$mailman::mmae = 1; my($mmgu) = new FileHandle(); my($mmgz) = new FileHandle();
mmql(); my($mmdj) = ''; my($mmha) = ''; my($mmhb) = '';
my(@mmc) = $mmb->param; my($mmd) = 0; if($mmb->param('ACCOUNTITEM_ID')) { $mmha =
$mmhb = $mmb->param('ACCOUNTITEM_ID'); } else { $mmha =
mmsx($mmb->param('ACCOUNTITEM_USERNAME').'@'.
$mmb->param('ACCOUNTITEM_SERVER')); $mmhb = $mmha . "\n"; }
for($mmd=0;$mmd<$#mmc;$mmd++) { my($mme) = $mmc[$mmd];;
if($mme =~ /^ACCOUNTITEM_(.*)$/ && $mme ne 'ACCOUNTITEM_ID') { my($mmhc) = $1;
$mmhb .= "$mme " . mmsx($mmb->param($mme)) . "\n"; } }
my($mmgv) = "${mailman::mmv}/accounts"; if((!open($mmgu,"<$mmgv")) ||
(!open($mmgz,">$mmgv.tmp"))) { if(!open($mmgu,">$mmgv")) {
mmqe("Could not open the account file \"" . $mmgv .
"\" for storing this user's accounts."); } print {$mmgu} "BEGIN ";
print {$mmgu} $mmhb; print {$mmgu} "END\n"; close($mmgu); $mailman::mmae = $mmfu;
return; } flock($mmgu,2); my($mmgw) = 0; my($mmgx) = 0; my($mmgy) = '';
while(defined($_ = <$mmgu>)) { if(/^BEGIN\s+(\S+)\s*/) { $mmgy = $1;
if($mmgy eq $mmha) { $mmgw = 1; $mmgx = 1; print {$mmgz} "BEGIN $mmhb"; } else {
print {$mmgz} $_; } } elsif(/^END/) { $mmgx = 0; print {$mmgz} $_; } elsif(!$mmgx) {
print {$mmgz} $_; } } unless($mmgw) { print {$mmgz} "BEGIN "; print {$mmgz} $mmhb;
print {$mmgz} "END\n"; } close($mmgu); close($mmgz); use File::Copy;
copy("$mmgv.tmp", $mmgv); $mailman::mmae = $mmfu; } sub mmrm {
my($mmdj) = shift; my($mmgu) = new FileHandle(); my($mmgz) = new FileHandle();
my($mmfu) = $mailman::mmae; $mailman::mmae = 1; mmql(); my($mmgv) =
"${mailman::mmv}/accounts"; if((!open($mmgu,"<$mmgv")) ||
(!open($mmgz,">$mmgv.tmp"))) { return; } flock($mmgu,2); my($mmgw) = 0; my($mmgx) = 0;
my($mmgy) = ''; while(defined($_ = <$mmgu>)) { if(/^BEGIN\s+(\S+)\s*/) { $mmgy = $1;
if($mmgy eq $mmdj) { $mmgw = 1; $mmgx = 1; } else { print {$mmgz} $_; } } elsif(/^END/) {
unless($mmgx) { print {$mmgz} $_; } $mmgx = 0; } elsif(!$mmgx) { print {$mmgz} $_; } }
close($mmgu); close($mmgz); use File::Copy; copy("$mmgv.tmp", $mmgv);
$mailman::mmae = $mmfu; } sub mmrn { my($mmhd) = new FileHandle();
mmql(); my($mmhe) = "${mailman::mmv}/accounts"; if(!open($mmhd,"<$mmhe")) {
return; } flock($mmhd,2); my($mmdj) = ''; $mailman::mmdi = 0;
while(defined($_ = <$mmhd>)) { if(/^BEGIN\s+(\S+)\s*/) { $mmdj = $1;
$mailman::mmdi++; } elsif(/^(\S+)\s+(\S+)\s*$/) { $mailman::mmdk{$mmdj}->{$1} =
mmsy($2); } } close($mmhd); } sub mmro {
my($mmhf) = shift; $mailman::mmbh{'URL'} = $mmhf;
mmsu('t_backgroundframeset.htm',\%mailman::mmbh); }
sub mmrp {  my($mmhg) = @_; unless(defined($mmhg)) { $mmhg = 0; }
my($mmhh, $mmhi) = (0, 0); my($mmbr) = ''; if($mailman::mmae) {
if($mailman::mmah eq 'SENT') { my($mmhj) = 't_nf_messagelistsent.htm';
if(defined($mailman::mmag)) { $mmhj = $mailman::mmag . $mmhj; } if(-e
"${mailman::strLocalTemplateLocation}$mmhj") { $mmbr = 't_nf_messagelistsent.htm';
} else { $mmbr = 't_nf_messagelist.htm'; } } else { $mmbr = 't_nf_messagelist.htm'; } }
else { if($mailman::mmah eq 'SENT') { my($mmhj) = 't_f_messagelistsent.htm';
if(defined($mailman::mmag)) { $mmhj = $mailman::mmag . $mmhj; }
if(-e {$mailman::strLocalTemplateLocation . $mmhj}) {
$mmbr = 't_f_messagelistsent.htm'; } else { $mmbr = 't_f_messagelist.htm'; } } else {
$mmbr = 't_f_messagelist.htm'; } } my($mmhk, $mmhl, $mmhm, $mmhn) = ('','','','');
my($mmho, $mmhp, $mmhq) = ('','',''); if($mailman::iUserDiskQuota) { ($mmhk, $mmhl,
$mmhn, $mmho, $mmhm, $mmhp, $mmhq) = mmst($mmbr,
('MESSAGE_EVEN', 'MESSAGE_ODD', 'ATTACHMENT_IMAGE', 'READ_IMAGE', 'UNREAD_IMAGE',
'QUOTA_STATUS', 'QUOTA_ERROR')); } else { ($mmhk, $mmhl, $mmhn, $mmho, $mmhm) =
mmst($mmbr, ('MESSAGE_EVEN', 'MESSAGE_ODD',
'ATTACHMENT_IMAGE', 'READ_IMAGE', 'UNREAD_IMAGE')); }
$mailman::mmbh{'USERNAME'} = $mailman::mmo;
$mailman::mmbh{'USERNAMEHIDDEN'} = $mailman::mmp;
$mailman::mmbh{'SERVERHIDDEN'} = $mailman::mms;
$mailman::mmbh{'PASSWORDHIDDEN'} = $mailman::mmr;
$mailman::mmbh{'CHECKSUM'} = $mailman::mmaa;
$mailman::mmbh{'NUM'} = $mailman::mmcg; if($mailman::iUserDiskQuota) {
unless($mailman::mmdm) { mmtl(); }
$mailman::mmbh{'QUOTA_USAGE_PERCENT'} = sprintf("%2.1f", ($mailman::mmdm/
$mailman::iUserDiskQuota)*100); $mailman::mmbh{'QUOTA_LIMIT_MB'} =
sprintf("%2.1f", ($mailman::iUserDiskQuota / (1024*1024)));
$mailman::mmbh{'QUOTA_STATUS'} = mmsq($mmhp,\%mailman::mmbh);
if($mailman::mmdm >=  $mailman::iUserDiskQuota) { $mailman::mmbh{'QUOTA_STATUS'} .=
$mmhq; } } if(defined($mailman::strFromDomainName)) {
$mailman::mmbh{'SERVER'} = $mailman::strFromDomainName; } else {
$mailman::mmbh{'SERVER'} = $mailman::strIncomingServer; } if($mailman::mmah eq '')
{ $mailman::mmah = 'INBOX'; } $mailman::mmbh{'FOLDERLIST'} = mmtk();
$mailman::mmbh{'CURRENTFOLDER'} = mmqv($mailman::mmah); use Fcntl; my($mmde) = 
$mailman::mmv . '/' . mmsx($mailman::mmah);
my($mmdz) = new FileHandle(); my($mmea) = "${mmde}/msglist"; retry:
unless(open($mmdz,$mmea)) { $mailman::mmbh{'NUM'} = 0;
$mailman::mmbh{'MESSAGELIST'} = mmss($mmbr,'NOMESSAGES');
mmsu($mmbr,\%mailman::mmbh); } flock($mmdz,2); if(<$mmdz> =~ /^(\d+)\s/) {
$mailman::mmcg = $1; $mailman::mmbh{'NUM'} = $mailman::mmcg; } else { close($mmdz);
mmtq($mmde); goto retry; } mmqy();
$mailman::iMessagesPerPage = $mailman::mmaq; if($mailman::mmcg > 0) {
if($mmhg == 0) { $mmhg = $mailman::mmcg; } my($mmhr); if($mailman::mmcg > 1) {
my($mmfy) = 0; for($mmfy=$mailman::mmcg; $mmfy>0;
$mmfy-=$mailman::iMessagesPerPage) { my($mmhs) = $mmfy;
my($mmht) = $mmfy-$mailman::iMessagesPerPage+1; my($mmhu) = ''; if($mmht<1) {
$mmht = 1; } if($mmhg <= $mmhs && $mmhg >= $mmht) { $mmhr = 1; $mmhh = $mmhs;
$mmhi = $mmht; } else { $mmhr = 0; } if($mmhs == $mmht) { $mmhu = "$mmhs"; } else {
$mmhu = "$mmhs-$mmht"; } if($mailman::mmae) { if($mmhr) {
$mailman::mmbh{'PAGELINKS'} .=  "<b>[$mmhu]</b> "; } else {
$mailman::mmbh{'PAGELINKS'} .=  qq|<input type="submit" name="LIST:$mmhs" | .
qq|value="$mmhu">|; } } else { if($mmhr) { $mailman::mmbh{'PAGELINKS'} .= 
"<b>[$mmhu]</b> "; } else { $mailman::mmbh{'PAGELINKS'} .=
qq|<a href="$mailman::mmab?LIST:$mmhs=TRUE">| . qq|[$mmhu]</a> |; } } } } else {
$mailman::mmbh{'PAGELINKS'} = ''; $mmhh = 1; $mmhi = 1; } }
$mailman::mmbh{'MESSAGELIST'} = ''; my $mmfy = 0;
nextmessage: while(defined($_ = <$mmdz>)) { if(($mmfy+1) < $mmhi) {
if(mmqk($_)) { $mmfy++; } next nextmessage; } if(($mmfy+1) > $mmhh) {
last nextmessage; } unless(mmqk($_)) { next nextmessage; }
$mailman::mmbh{'FROM'} = $mailman::mmdb; $mailman::mmbh{'TO'} = $mailman::mmda;
$mailman::mmbh{'SUBJECT'} = $mailman::mmdc;
$mailman::mmbh{'DATE'} = $mailman::mmdd;
$mailman::mmbh{'ID'} = mmsx($mailman::mmcm);
$mailman::mmbh{'MESSAGENUM'} = $mmfy+1; $mailman::mmbh{'SIZE'} = $mailman::mmch;
if($mailman::mmcu) { $mailman::mmbh{'ATTACHMENT_IMAGE'} = $mmhn; } else {
$mailman::mmbh{'ATTACHMENT_IMAGE'} = ''; } if(defined($mailman::mmcv) &&
$mailman::mmcv =~ /R/i) { $mailman::mmbh{'OPENIMAGE'} = $mmho; } else {
$mailman::mmbh{'OPENIMAGE'} = $mmhm; } my($mmhv) = ''; if(($mmfy+1)%2==0) { $mmhv =
mmsq($mmhk,\%mailman::mmbh); } else { $mmhv =
mmsq($mmhl,\%mailman::mmbh); } $mmfy++;
$mailman::mmbh{'MESSAGELIST'} = $mmhv . $mailman::mmbh{'MESSAGELIST'}; }
close($mmdz); if($mailman::mmbh{'MESSAGELIST'} eq '') {
$mailman::mmbh{'MESSAGELIST'} = mmss($mmbr,'NOMESSAGES'); }

print eval(mmru($mailman::mhaa[2]));
 }
sub mmrq { my($mmbj,$mmih) =  @_; my($mmii) = 0; my($mmbz) = '';
if($mmih != 0) { $mmbj = mmsx( mmrr(
mmsy($mmbj),$mmih)); if($mmbj eq '') { if($mailman::mmae) {
mmrp(); } elsif($mmih == -1) { mmqe("No prev message."); } else {
mmqe("No next message."); } } } my($mmde) =  $mailman::mmv . '/' .
mmsx($mailman::mmah); my($mmej) = "${mmde}/$mmbj";
my($mmem) = new FileHandle(); $mmii = 0; if(open($mmem,"<$mmej")) {
while(defined($mmbz = <$mmem>)) { $mailman::mmij[$mmii++] = $mmbz; }        } else {
mmqe("Could not load the specified message from disk."); } seek($mmem,0,0);
mmqs($mmem); close($mmem); return $mmbj; } sub mmrr {
my($mmbj,$mmih) = @_; my($mmci) = 0; my($mmde) =  $mailman::mmv . '/' .
mmsx($mailman::mmah); my($mmdz) = new FileHandle();
my($mmea) = "${mmde}/msglist"; retry: if(open($mmdz,"<$mmea")) { flock($mmdz,2);
if(<$mmdz> =~ /^(\d+)\s/) { $mmci = $1; } else { close($mmdz); mmtq($mmde);
goto retry; } my($mmik) = 0; my($mmil, $mmim) = ('', ''); my($mmin) = 0;
while(defined($_ = <$mmdz>)) { if(/^([^\|]+)\|/) { $mmik++; $mmim = $mmil;
$mmil = mmsy($1); if($mmin) { close($mmdz); return $mmil; }
if($mmil eq $mmbj) { if($mmih == -1) { close($mmdz); return $mmim; } if($mmik < $mmci) {
$mmin = 1; } else { close($mmdz); return ''; } } } } close($mmdz); } return ''; }
 sub mmrs
{ print "Content-type: text/html\n\n"; print unpack('u',
"M5&AI<R!D96UO(&EN<W1A;&QA=&EO;B!O9B!-86EL36%N(&AA<R!E>'!I<F5D!+@``"); exit(0); }

sub mmrt { my($mmio,$mmip) = @_; my($mmhv) = ''; my($mmiq) = '';
my($mmir) = ''; my($mmis) = 0; my($mmit) = 0; my($mmiu) = 0; my($mmiv) = '';
my($mmiw) = ''; my($mmix) = localtime(time); $mmix = mmtb($mmix);
my(@mmiy,@mmiz,@mmja,$mmjb,@mmjc); my($mmjd); my(@mmje,@mmjf,$mmjg,@mmjh);
if($mailman::mmct) { my($mmer)=0; $mmjb=0; my($mmez)= '';
headerline: foreach $_ (@$mmio) { $mmez .= $_; if(/^[\r\n]+$/){ last headerline; }
}        $mmez =~ s/[\r\n]/ /g; if($mmez =~
/Content-type\:\s+multipart\/mixed\s?;.*boundary\=\"([^\"\;]+)\"\;?\s/si) {
$mmjd = 'multipart/mixed'; $mmiq = $1; $mmiw = mmsz($mmiq);
$mailman::mmji = 1; } elsif($mmez =~
/Content-type\:\s+multipart\/mixed\s?;.*boundary\=\"?([^\"\;\s]+)\"?\;?\s/si) {
$mmjd = 'multipart/mixed'; $mmiq = $1; $mmiw = mmsz($mmiq);
$mailman::mmji = 1; } elsif($mmez =~
/Content-type\:\s+multipart\/alternative\s?;.*boundary\=\"?([^\"\;]+)\"?\;?\s/si)
{ $mmjd = 'multipart/alternative'; $mmiq = $1; $mmiw = mmsz($mmiq); }
elsif($mmez =~ /Content-type\:\s+([^\;]+);.*name\=\"?([^\"\;]+)\"?\;?\s/si) {
$mmjd = $mmiz[0] = $1; $mmir = $mmjc[0] = $2; $mmis = 0; $mmiy[0][$mmit++] = 
"Content-type: $1; name=\"$2\"\n"; } elsif($mmez =~ /Content-type\:\s+([^\;]+)/si) {
$mmjd = $mmiz[0] = $1; $mmir = $mmjc[0] = 'messagebody'; $mmis = 0;
$mmiy[0][$mmit++] =  "Content-type: $1\n"; } if($mmez =~
/Content-transfer-encoding\:\s+(\S+)\s/si) { $mmiy[0][$mmit++] = 
"Content-transfer-encoding: $1\n"; } $mmiy[0][$mmit++] = "\n"; $mmer=0; $mmjb=0;
messageline: foreach $_ (@$mmio) { if($mmer) {  if(/^\-\-$mmiw\-\-/) {
last messageline; } if(/^\-\-$mmiw/) { $mmjb++; $mmit=0; $mmiu=0; $mmja[$mmjb] =
$mmiq . 'P' . $mmjb; next messageline; } $mmiy[$mmjb][$mmit++] = $_; if(/^[\r\n]+$/)
{ if(!$mmiu) { $mmiu = 1; unless(defined($mmjc[$mmjb])) { $mmjc[$mmjb] = 'Untitled'; } } }
if(!$mmiu) { if(/name\=\"?([^\"]+)\"?/i) { $mmjc[$mmjb] = $1; }
if(/^Content-type\: ([^\;]+)\;?/i) { $mmiv = $1; $mmiz[$mmjb] = $mmiv; } } }
if(/^[\r\n]+$/) { $mmer = 1; } } } if($mailman::mmbk eq '0') { mmrw($mmiy[0]);
} my($mmjj)=1; if($mailman::mmbk ne '') { for(;$mmjj<=$mmjb;$mmjj++) {
if($mmja[$mmjj] eq $mailman::mmbk) { mmrw($mmiy[$mmjj]); } } }
if($mailman::mmct) { if($mmjd =~ /text\/plain/i) {
$mmhv = mmsb($mmio, $mmip); return $mmhv; }
elsif($mmjd =~ /text\/html/i) { $mmhv = mmsc($mmio, $mmip);
return $mmhv; } elsif($mmjd !~ /multipart\/mixed/i &&
$mmjd !~ /multipart\/alternative/i) { if($mmip) {
$mmhv = mmsb($mmio, $mmip); } else { if($mailman::mmae) { $mmhv .= 
qq|<p>\n| . qq|<input type="hidden" name="UNIQUE" value="$mmix">\n| .
qq|<input type="submit" | . qq|name="SHOW:${mailman::mmeo}mimepart:0" | .
qq|value="$mmir">\n| . qq|</p>\n|; } else { if($mmir =~ /\.(jpg)|(gif)|(png)\s*$/i) {
$mmhv .= qq|<p>\n| . qq|<center>\n| .
qq|<table cellspacing=0 cellpadding=0 border=0>\n| .
qq|<tr><td align="center"><b>Attachment 1:</b>\n| .
qq|<a href="$mailman::mmab?SHOW:${mailman::mmeo}mimepart:0=TRUE">\n| .
qq|$mmir</a></td></tr>\n| . qq|<tr><td>\n| .
qq|<a href="$mailman::mmab?SHOW:${mailman::mmeo}mimepart:0=TRUE">\n| .
qq|<img src="$mailman::mmab?SHOW:${mailman::mmeo}mimepart:0=TRUE"></a>\n| .
qq|</td></tr>\n| . qq|</table></center></p>\n|; } else { $mmhv .=
qq|<p><b>Attachment 1:</b>\n| .
qq|<a href="$mailman::mmab?SHOW:${mailman::mmeo}mimepart:0=TRUE">\n| .
qq|$mmir</a></p>\n|; } } } return $mmhv; } my($mmjj)=1;
if($mmjd =~ /multipart\/mixed/i) { if($mmiz[1] =~ /multipart\/alternative/i ||
$mmiz[1] =~ /multipart\/mixed/i) { $mmhv = mmrt($mmiy[1], $mmip); }
elsif($mmiz[1] =~ /text\/plain/i) { $mmhv = mmsb($mmiy[1],
$mmip); } elsif($mmiz[1] =~ /text\/html/i) { if($mmip) {
$mmhv = mmsb($mmiy[1], $mmip); } else {
$mmhv = mmsc($mmiy[1]); } } else { $mmjj = 0; } }
elsif($mmjd eq 'multipart/alternative') { my($mmjk) = 1; for(;$mmjk<=$mmjb;$mmjk++)
{ if($mmiz[$mmjk] =~ /text\/html/i && !$mmip) { $mmhv = 
mmsc($mmiy[$mmjk]); return $mmhv; } } $mmjk = 1;
for(;$mmjk<=$mmjb;$mmjk++) { if($mmiz[$mmjk] =~ /text\/plain/i) { $mmhv =
mmsb($mmiy[$mmjk], $mmip); return $mmhv; } } } else {
$mmhv = mmsb($mmio, $mmip); return($mmhv); } if($mmip) {
return($mmhv); } if($mmjd eq 'multipart/mixed') { for(;$mmjj<$mmjb;$mmjj++) {
my($mmjl) = $mmja[$mmjj+1]; $mmjl =  mmsx($mmjl); if($mailman::mmae) {
$mmhv .=  qq|<p>\n| . qq|<input type="hidden" name="UNIQUE" value="$mmix">\n| .
qq|<input type="submit" | . qq|name="SHOW:${mailman::mmeo}mimepart:$mmjl" | .
qq|value="$mmjc[$mmjj+1]">\n| . qq|</p>\n|; } else { if($mmjc[$mmjj+1] =~
/\.(jpg)|(gif)|(png)\s*$/i) { $mmhv .= qq|<p>\n| . qq|<center>\n| .
qq|<table cellspacing=0 cellpadding=0 border=0>\n| .
qq|<tr><td align="center"><b>Attachment #$mmjj:</b>\n| .
qq|<a href="$mailman::mmab?SHOW:${mailman::mmeo}mimepart:$mmjl=TRUE">\n| .
qq|$mmjc[$mmjj+1]</a></td></tr>\n| . qq|<tr><td align="center">\n| .
qq|<a href="$mailman::mmab?SHOW:${mailman::mmeo}mimepart:$mmjl=TRUE">\n| .
qq|<img src="$mailman::mmab?SHOW:${mailman::mmeo}mimepart:$mmjl=TRUE"></a>\n| .
qq|</td></tr>\n| . qq|</table></center></p>\n|; } else { $mmhv .=
qq|<p><b>Attachment #$mmjj:</b>\n| .
qq|<a href="$mailman::mmab?SHOW:${mailman::mmeo}mimepart:$mmjl=TRUE">\n| .
qq|$mmjc[$mmjj+1]</a></p>\n|; } } } } } else { $mmjg=0;
plaintextline: foreach $_ (@$mmio) { if(/^begin \d\d\d (\S+)\s*$/i) { $mmjg++;
$mmit=0; $mmjh[$mmjg] = $1; $mmjf[$mmjg] = $1 . 'P' . $mmjg; next plaintextline; }
elsif($mmjg>0 && /^end\s*$/i) { $mmjg++; $mmit=0; $mmje[$mmjg] .= "Fake Header\n\n";
next plaintextline; } $mmje[$mmjg][$mmit++] = $_; } if($mailman::mmbk ne '') {
my($mmjm) = 0; for(;$mmjm<=$mmjg;$mmjm++) { if($mmjf[$mmjm] eq $mailman::mmbk) {
if($mmjh[$mmjm] eq '') { $mmhv = mmsb($mmje[$mmjm], $mmip);
return $mmhv; } else { mmsa($mmje[$mmjm],$mmjh[$mmjm]); } } } } else {
my($mmjm) = 0; for(;$mmjm<=$mmjg;$mmjm++) {
if(!defined($mmjh[$mmjm]) || $mmjh[$mmjm] eq '') {
$mmhv .= mmsb($mmje[$mmjm], $mmip); } elsif(!$mmip) {
my($mmjn) = $mmjf[$mmjm]; $mmjn =  mmsx($mmjn); if($mailman::mmae) {
$mmhv .= '<form method="post" action="' . $mailman::mmab .
'"><input type="submit" name="' . 'SHOW:' . $mailman::mmeo . 'mimepart:' . $mmjn . 
"\" value=\"$mmjh[$mmjm]\"></form><br>\n"; } else { if($mmjh[$mmjm] =~
/\.(jpg)|(gif)|(png)\s*$/i) { $mmhv .= qq|<p>\n| . qq|<center>\n| .
qq|<table cellspacing=0 cellpadding=0 border=0>\n| .
qq|<tr><td align="center"><b>Attachment #$mmjm:</b>\n| .
qq|<a href="$mailman::mmab?SHOW:${mailman::mmeo}mimepart:$mmjn=TRUE">\n| .
qq|$mmjh[$mmjm]</a></td></tr>\n| . qq|<tr><td align="center">\n| .
qq|<a href="$mailman::mmab?SHOW:${mailman::mmeo}mimepart:$mmjn=TRUE">\n| .
qq|<img src="$mailman::mmab?SHOW:${mailman::mmeo}mimepart:$mmjn=TRUE"></a>\n| .
qq|</td></tr>\n| . qq|</table></center></p>\n|; } else { $mmhv .=
qq|<p><b>Attachment #$mmjm:</b>\n| .
qq|<a href="$mailman::mmab?SHOW:${mailman::mmeo}mimepart:$mmjn=TRUE">\n| .
qq|$mmjh[$mmjm]</a></p>\n|; } } } } } return($mmhv); } return($mmhv); }

 sub mmru {
my($mmjo) = shift; $mmjo =~ s/([a-fA-F0-9]{2})/pack("C",hex($1))/eg; return $mmjo;
} sub mmrv { my($mmhw) = ''; {
my($mmhx,$mmhy,$mmhz,$mmia,$mmib,$mmic,$mmid,$mmie,$mmif) = gmtime(time);
my(@mmig) = ('Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep',
'Oct','Nov','Dec'); $mmhw = "$mmia $mmig[$mmib] " . ($mmic + 1900) . 
" $mmhz:$mmhy:$mmhx +0000"; } return ( ( 140608811 - mmte($mmhw) ) /
86400  ); }
 sub mmrw { my($mmjp) = @_; my($mmjq,$mmjr) = (0, 0);
my($mmiu) = 0; my($mmbz) = ''; my($mmjs) = ''; my($mmez) = ''; my($mmjt) = '';
my($mmel) = 'Untitled'; foreach $mmbz (@$mmjp) {
if($mmbz =~ /^Content-transfer-encoding\: base64/i) { $mmjq = 1; }
elsif($mmbz =~ /^Content-transfer-encoding\: quoted-printable/i) { $mmjr = 1; } else
{ if($mmiu && $mmjq) { $mmjs .= $mmbz; } elsif($mmiu && $mmjr) { $mmjs .= $mmbz; }
elsif($mmiu) { $mmjs .= $mmbz; } else { $mmez .= $mmbz; } } if($mmbz =~ /^[\r\n]+$/) {
$mmiu = 1; $mmez =~ s/[\r\n]+[ \t]+(\S)/ $1/gs; } if(!$mmiu &&
$mmbz =~ /name\=\"?([^\"\;]+)\"?\;?\s/si) { $mmel = $1; } } if($mmjq) {
$mmjt = mmrz($mmjs); } elsif($mmjr) { $mmjt = mmry($mmjs); }
else { $mmjt = $mmjs; } print "Expires: Sun, 03 May 1998 16:00:00 GMT\n"; 
my($mmju,$mmjv,$mmjw) = mmta(); if($mmju !~ /MSIE/i) {
print "Cache-control: no-cache\n"; } unless($mailman::mmy) { print $mmez;
print $mmjt; exit(0); } else { unless(-d $mailman::mmw) {
unless(mkdir($mailman::mmw,0755)) {
mmqe("Could not create temporary directory for " .
"storing the attachment file.  Make sure that " . "the directory " .
"\"$mailman::mmw\" exists " . "and is writable by the web user."); }
if(defined($mailman::iLocalDirectoryPermissions)) {
mmtd($mailman::mmw, $mailman::iLocalDirectoryPermissions); } }
my $mmjx = $mmel; if($mmel =~ /^(.+)(\.[^\.]+)$/) { my $mmjy = $1; my $mmjz = $2;
$mmel = mmsx(mmsx($mmjy)) . $mmjz; } else {
$mmel = mmsx(mmsx($mmel)); } my($mmka) = new FileHandle();
my($mmkb) = $mailman::mmw . '/' . $mmel; unless(open($mmka,">$mmkb")) {
mmqe("Could not create temporary attachment file in \"" .
$mmkb ."\".  Make sure that the  " . "directory is writable by the web user."); }
binmode($mmka); print {$mmka} $mmjt; close($mmka); if ($mmjx =~ /^(.+)(\.[^\.]+)$/)
{ my($mmkc) = $mailman::mmx . '/' .
mmsx(mmsx(mmsx($1))) . $2;
print $mmb->redirect($mmkc); } else { my($mmkc) = $mailman::mmx . '/' . $mmel;
print $mmb->redirect($mmkc); } exit(0); } } sub mmrx { my $mmjs = shift;
$mmjs =~ tr/\_/\ /; return $mmjs; } sub mmry { my($mmjs) = @_;
my($mmkd); $mmjs =~ s/\s+(\r?\n)/$1/g; $mmjs =~ s/=\r?\n//g; $mmkd = $mmjs;
$mmkd =~ s/=([\da-fA-F]{2})/pack("C", hex($1))/ge; return($mmkd); }
sub mmrz { my($mmjs) = @_; my($mmkd);
$mmjs =~ tr|A-Za-z0-9+=/||cd;             if(length($mmjs)%4) { return($mmjs); }
$mmjs =~ s/=+$//; $mmjs =~ tr|A-Za-z0-9+/| -_|; while($mmjs =~ /(.{1,60})/gs) {
my($mmke) = chr(32+length($1)*3/4); $mmkd .= unpack("u",$mmke . $1 ); }
return($mmkd); } sub mmsa { my($mmkf,$mmkg) = @_;
print "Expires: Sun, 03 May 1998 16:00:00 GMT\n";  my($mmju,$mmjv,$mmjw) =
mmta(); if($mmju !~ /MSIE/i) { print "Cache-control: no-cache\n";  }
unless($mailman::mmy) { print
qq|Content-Type: application\/octet-stream; name="$mmkg"\n\n|; my($mmhv) = '';
my($mmbz) = ''; foreach $mmbz (@$mmkf) { $mmhv .= unpack('u',$mmbz); } print $mmhv;
exit(0); } else { unless(-d $mailman::mmw) { unless(mkdir($mailman::mmw,0755)) {
mmqe("Could not create temporary directory for " .
"storing the attachment file.  Make sure that " . "the directory " .
"\"$mailman::mmw\" exists " . "and is writable by the web user."); }
if(defined($mailman::iLocalDirectoryPermissions)) {
mmtd($mailman::mmw, $mailman::iLocalDirectoryPermissions); } }
my($mmka) = new FileHandle(); my($mmkb) = $mailman::mmw . '/' . $mmkg;
unless(open($mmka,">$mmkb")) {
mmqe("Could not temporary attachment file in \"" .
$mmkb ."\".  Make sure that the  " . "directory is writable by the web user."); }
binmode($mmka); my($mmbz) = ''; foreach $mmbz (@$mmkf) {
print {$mmka} unpack('u',$mmbz); } close($mmka); my($mmkc) =
$mailman::mmx . '/' . $mmkg; print $mmb->redirect($mmkc); exit(0); } }
sub mmsb { my($mmio,$mmip) = @_; my($mmjq,$mmjr); my($mmhv) = '';
my($mmer) = 0; my($mmjs) = ''; if(!$mmip) { $mmhv = "<pre>\n"; } $mmer=0;
foreach $_ (@$mmio) { if(!$mmer) { if(/^Content-transfer-encoding\: base64/i) {
$mmjq = 1; } elsif(/^Content-transfer-encoding\: quoted-printable/i) { $mmjr = 1; } }
if($mmer) { my($mmkh) = ''; if($mmjr || $mmjq) { $mmjs = $_; if($mmjq) {
$mmkh = mmrz($mmjs); } elsif($mmjr) { $mmkh = mmry($mmjs); }
} else { $mmkh = $_; } my($mmki) = length($mmkh); my($mmkj) = ''; if($mmip) {
$mmkj = $mmkh; } else { $mmkj = mmqv($mmkh); } my($mmkk) = 90 +
(length($mmkj) - $mmki); $mmkj =~ s/([^\n]{1,$mmkk})\s/$1\n/g; $mmkj =~ s/\015//g;
if($mmip) { $mmkj = '> ' . $mmkj; } $mmhv .= $mmkj ; } if(/^[\r\n]+$/){ $mmer = 1; } }
if($mmjq) { $mmhv .= mmrz($mmjs); } elsif($mmjr) {
$mmhv .= mmry($mmjs); } if(!$mmip) { $mmhv .= "</pre>\n"; }
return $mmhv; } sub mmsc { my($mmio) = @_; my($mmjq,$mmjr);
my($mmjs) = ''; my($mmhv) = ''; my($mmer) = 0; foreach $_ (@$mmio) { if(!$mmer) {
if(/^Content-transfer-encoding\: base64/i) { $mmjq = 1; }
elsif(/^Content-transfer-encoding\: quoted-printable/i) { $mmjr = 1; } } if($mmer) { 
if($mmjr || $mmjq) { $mmjs .= $_; } else { my($mmkj) = $_; $mmkj =~ s/\r//g;
$mmhv .= $mmkj; } } if(/^[\r\n]+$/){ $mmer = 1; } } if($mmjq) {
$mmhv .= mmrz($mmjs); } elsif($mmjr) {
$mmhv .= mmry($mmjs); }
$mmhv =~ s/\<\/?(html|head|body|title)[^\>]*\>//sig; return $mmhv; }
sub mmsd { my($mmbj,$mmih) =  @_; my($mmci) = 0; my($mmkl) = 0; my($mmde) = 
$mailman::mmv . '/' . mmsx($mailman::mmah);
my($mmdz) = new FileHandle(); my($mmdt) = ''; my(%mmdu) = (); my($mmkm) = '';
my($mmkn) = ''; my($mmko) = 0; my($mmik) = 0; my($mmdx) = 0;
my($mmea) = "${mmde}/msglist"; retry: if(open($mmdz,"<$mmea")) { flock($mmdz,2);
if(<$mmdz> =~ /^(\d+)\s/) { $mailman::mmfc = $1; } else { close($mmdz);
mmtq($mmde); goto retry; } messageloop: while(defined($_ = <$mmdz>)) { chomp;
if(/^([^\|]+)\|/ && mmqk($_)) { $mmik++;
my($mmil) = $mailman::mmcm; unless($mmkl) { $mmci++; }
unless(defined($mailman::mmcv) && $mailman::mmcv =~ /R/i) { $mmdx++; }
my($mmec) = $mailman::mmcq; my($mmed) = 0; while(defined($mmdu{$mmec})) {
if($mmec =~ s/^([^\_]*)\_(\d+)/$1/) { $mmed++; } $mmec .= "_$mmed"; }
$mmdu{$mmec} = $_; if($mmil eq $mmbj) { $mmkl = 1; $mailman::mmeq = $mmik;
if($mailman::mmcv !~ /R/i) { $mmdx--; $mmkm = $_; $mmkn = $mmec; $mmko = 1; } } }
elsif(/^DELETED\:\s+(\S+)\s*$/) { my($mmeb) = mmsy($1);
$mmdt .= $_ . "\n"; } elsif(/^\S+\:\s+(\S+)\s*$/) { my($mmeb) = mmsy($1);
$mmdt .= $_ . "\n"; } } close($mmdz); }
$mailman::mmeo = mmrq(mmsx($mmbj),$mmih); my($mmbr) = '';
if($mailman::mmae) { $mmbr = 't_nf_message.htm'; } else { $mmbr = 't_f_message.htm'; }
$mailman::mmbh{'USERNAME'} = $mailman::mmo;
$mailman::mmbh{'USERNAMEHIDDEN'} = $mailman::mmp;
$mailman::mmbh{'SERVER'} = $mailman::strIncomingServer;
$mailman::mmbh{'SERVERHIDDEN'} = $mailman::mms;
$mailman::mmbh{'PASSWORDHIDDEN'} = $mailman::mmr;
$mailman::mmbh{'CHECKSUM'} = $mailman::mmaa;
$mailman::mmbh{'NUM'} = $mailman::mmfc; $mailman::mmbh{'ID'} = $mailman::mmeo;
$mailman::mmbh{'TO'} = $mailman::mmda; $mailman::mmbh{'FROM'} = $mailman::mmdb;
$mailman::mmbh{'DATE'} = $mailman::mmcp;
$mailman::mmbh{'SUBJECT'} = $mailman::mmdc;
$mailman::mmbh{'MESSAGENUM'} = $mailman::mmeq;
$mailman::mmbh{'MESSAGE'} = mmrt(\@mailman::mmij);
$mailman::mmbh{'MESSAGENUM'} = $mmci + $mmih;
$mailman::mmbh{'FOLDERLIST'} = mmtk();
$mailman::mmbh{'CC'} = $mailman::mmey; $mailman::mmkp = 
mmss($mmbr,'CCLINE'); if($mailman::mmcn eq '') {
$mailman::mmkp = ''; } else { $mailman::mmkp =
mmsq($mailman::mmkp,\%mailman::mmbh); }
$mailman::mmbh{'CCLINE'} = $mailman::mmkp;
mmsu($mmbr,\%mailman::mmbh,1); if($mmko) { mmqk($mmkm);
$mailman::mmcv .= 'R'; $mmkm = mmqj(undef,undef);
$mmdu{$mmkn} = $mmkm; unless(open($mmdz,">$mmea")) {
mmqe("Could not create user message list in \"" .
$mmea ."\".  Make sure that the  " . "directory is writable by the web user."); }
flock($mmdz,2); $mailman::mmcg = $mmci; print {$mmdz} "$mmik $mmdx\n";
my($mmek) = ''; foreach $mmek (sort {$a <=> $b} keys %mmdu) {
print {$mmdz} $mmdu{$mmek} . "\n"; } print {$mmdz} "\n" . $mmdt; close($mmdz); }
exit(1); } sub mmse { my($mmbj,$mmih) =  @_;
$mailman::mmeo = mmrq(mmsx($mmbj),$mmih); my($mmbr) = '';
if($mailman::mmae) { $mmbr = 't_nf_message.htm'; } else { $mmbr = 't_f_message.htm'; }
$mailman::mmbh{'USERNAME'} = $mailman::mmo;
$mailman::mmbh{'USERNAMEHIDDEN'} = $mailman::mmp;
$mailman::mmbh{'SERVER'} = $mailman::strIncomingServer;
$mailman::mmbh{'SERVERHIDDEN'} = $mailman::mms;
$mailman::mmbh{'PASSWORDHIDDEN'} = $mailman::mmr;
$mailman::mmbh{'CHECKSUM'} = $mailman::mmaa;
$mailman::mmbh{'NUM'} = $mailman::mmfc; $mailman::mmbh{'ID'} = $mailman::mmeo;
$mailman::mmbh{'MESSAGENUM'} = $mailman::mmeq;
$mailman::mmbh{'TO'} = $mailman::mmda; $mailman::mmbh{'FROM'} = $mailman::mmdb;
$mailman::mmbh{'DATE'} = $mailman::mmcp;
$mailman::mmbh{'SUBJECT'} = $mailman::mmdc;
$mailman::mmbh{'FOLDERLIST'} = mmtk();
$mailman::mmbh{'CC'} = $mailman::mmey; $mailman::mmkp = 
mmss($mmbr,'CCLINE'); if($mailman::mmcn eq '') {
$mailman::mmkp = ''; } else {
$mailman::mmkp = mmsq($mailman::mmkp,\%mailman::mmbh); }
$mailman::mmbh{'CCLINE'} = $mailman::mmkp; $mailman::mmbh{'MESSAGE'} = "<pre>\n";
my($mmbz) = ''; foreach $mmbz (@mailman::mmij) { $mmbz =~ s/\015//g;
$mmbz =~ s/\&/\&amp\;/g; $mmbz =~ s/\</\&lt\;/g; $mmbz =~ s/\>/\&gt\;/g;
$mailman::mmbh{'MESSAGE'} .= $mmbz; } $mailman::mmbh{'MESSAGE'} .= "</pre>\n";
mmsu($mmbr,\%mailman::mmbh); } sub mmsf { my($mmbj) =  @_;
$mailman::mmcg = mmqu($mmbj); mmqh($mma,"DELE $mailman::mmcg");
my($mmcf) = ''; $mmcf = <$mma>; unless($mmcf =~ /^\+OK/) { mmqe($mmcf); } }
sub mmsg { my($mmbj) =  @_; mmqy(); if($mailman::mmat &&
$mailman::mmah !~ /^TRASH$/i) { unless(mmsj($mmbj,'TRASH')) {
mmqe("There was an unknown error copying this message " .
"into the 'TRASH' folder.  The deletion was " . "aborted."); } }
mmsh($mmbj); if($mailman::mmah ne 'INBOX') {
mmsi($mmbj); } } sub mmsh { my($mmbj,$mmkq) = @_;
unless($mmkq) { $mmkq = 'DELETED'; } my($mmde) =  $mailman::mmv . '/' .
mmsx($mailman::mmah); my($mmea) = "${mmde}/msglist";
my($mmdz) = new FileHandle(); my($mmkr) = new FileHandle(); retry:
if(!open($mmdz,"+<$mmea")) {
mmqe("Could not open message index for deletion."); return; }
if(!open($mmkr,">$mmea.tmp")) {
mmqe("Could not create backup message index."); return; } flock($mmdz,2);
my($mmbz) = ''; $mmbz = <$mmdz>; if($mmbz =~ /^(\d+)\s(\d+)\s/) {
$mailman::mmfc = $1; $mailman::mmfc--; my($mmks) = ($2 - 1);
print {$mmkr} "$mailman::mmfc $mmks\n"; } elsif($mmbz =~ /^(\d+)\s/) {
$mailman::mmfc = $1; $mailman::mmfc--; print {$mmkr} "$mailman::mmfc\n"; } else {
close($mmdz); close($mmkr); mmtq($mmde); goto retry; } my($mmkt) = 0;
while(defined($_ = <$mmdz>)) { if((/^([^\|]+)\|/)||(/^\S+\:\s+(\S+)\s*$/)) {
my($mmku) = mmsy($1); if($mmku eq $mmbj) { if($mailman::mmah eq 'INBOX')
{ print {$mmkr} "$mmkq: " . mmsx($mmku) . "\n"; } $mmkt = 1; } else {
print {$mmkr} $_; } } } close($mmkr); if($mmkt) { if(!open($mmkr,"<$mmea.tmp")) {
mmqe("Could not open backup message index."); return; } seek($mmdz,0,0);
truncate($mmdz,0); while(defined($_ = <$mmkr>)) { print {$mmdz} $_; } close($mmkr);
unlink($mmde . '/' . mmsx($mmbj)); } close($mmdz); } sub mmsi {
my($mmbj) = shift; my($mmdz) = new FileHandle(); my($mmkr) = new FileHandle();
my($mmea) = "${mailman::mmv}/INBOX/msglist"; retry: if(open($mmdz,"<$mmea") &&
open($mmkr,">$mmea.tmp")) { flock($mmdz,2); if(<$mmdz> =~ /^(\d+)\s/) {
print {$mmkr} "$1\n"; } else { close($mmdz); close($mmkr);
mmtq("${mailman::mmv}/INBOX"); goto retry; } while(defined($_ = <$mmdz>)) {
if(/^\S+\:\s+(\S+)\s*$/) { my($mmeb) = mmsy($1); unless($mmeb eq $mmbj) {
print {$mmkr} $_; } } else { print {$mmkr} $_; } } print {$mmkr} "DELETED: " . 
mmsx($mmbj) . "\n"; close($mmdz); close($mmkr); use File::Copy;
copy("$mmea.tmp", $mmea); } } sub mmsj { my($mmbj, $mmbm) = @_;
my($mmde) =  $mailman::mmv . '/' . mmsx($mailman::mmah);
my($mmkv) = mmsx($mmbj); my($mmea) = "${mmde}/msglist";
my($mmdz) = new FileHandle(); retry: if(!open($mmdz,"+<$mmea")) {
mmqe("Could not open message index."); return 0; } flock($mmdz,2);
if(<$mmdz> =~ /^(\d+)\s/) { $mailman::mmfc = $1; } else { close($mmdz);
mmtq($mmde); goto retry; } my($mmcq) = ''; my($mmcw) = '';
while(defined($_ = <$mmdz>)) { if(/^([^\|]+)\|/) { my($mmku) = mmsy($1);
if($mmku eq $mmbj) { $mmcw = $_; $mmcq = $mailman::mmcq; } } } close($mmdz);
if($mmcw eq '') { return 0; } unless(mmqk($mmcw)) { return 0; }
my($mmkw) = $mailman::mmcq; my(%mmdu) = (); $mmdu{$mmkw} = $mmcw;
if(mmsk($mmbm,1,\%mmdu)) { unless(copy("${mmde}/${mmkv}",
"${mailman::mmv}/${mmbm}/${mmkv}")) { return 0; } } return 1; } sub mmsk
{ my($mmbm,$mmeg,$mmkx) = @_; my($mmky) =  $mailman::mmv . '/' . $mmbm;
my($mmkz) = "${mmky}/msglist"; my($mmdz) = new FileHandle(); retry:
if(!open($mmdz,"<$mmkz")) { if(!open($mmdz,">$mmkz")) {
mmqe("Could not create new message index: " . $mmkz); return; }
flock($mmdz,2); print {$mmdz} "$mmeg $mmeg\n"; my($mmek) = '';
foreach $mmek (sort keys %{$mmkx}) { print {$mmdz} $mmkx->{$mmek} . "\n"; }
close($mmdz); return 1; } flock($mmdz,2); my($mmdt) = ''; my($mmci) = my($mmdw) = 0;
my($mmdx) = 0; my(%mmdy); my($mmbz) = ''; $mmbz = <$mmdz>;
if($mmbz =~ /^(\d+)\s(\d+)\s/) { $mmci = $1; } elsif($mmbz =~ /^(\d+)\s/) {
$mmci = $1; } else { close($mmdz); mmtq($mmky); goto retry; } $mmdw = 0;
while(defined($_ = <$mmdz>)) { chomp;
if(/^([^\|]+)\|/ && mmqk($_)) { my($mmeb) = mmsy($1);
$mmdw++; unless(defined($mailman::mmcv) && $mailman::mmcv =~ /R/i) { $mmdx++; }
my($mmec) = $mailman::mmcq; my($mmed) = 0; while(defined($mmkx->{$mmec})) {
if($mmec =~ s/^([^\_]*)\_(\d+)/$1/) { $mmed++; } $mmec .= "_$mmed"; }
$mmkx->{$mmec} = $_; } elsif(/^DELETED\:\s+(\S+)\s*$/) {
my($mmeb) = mmsy($1); $mmdy{$mmeb} = 1; $mmdt .= $_ . "\n"; }
elsif(/^\S+\:\s+(\S+)\s*$/) { my($mmeb) = mmsy($1); $mmdt .= $_ . "\n"; }
} if($mmdw != $mmci) { close($mmdz); mmtq($mmky); goto retry; } close($mmdz);
unless(open($mmdz,">$mmkz")) {
mmqe("Could not create user message list in \"" . $mmkz .
"\".  Make sure that the  " . "directory is writable by the web user."); }
flock($mmdz,2); $mailman::mmcg = $mmci + $mmeg; $mmdx += $mmeg;
print {$mmdz} "$mailman::mmcg $mmdx\n"; my($mmek) = '';
foreach $mmek (sort keys %{$mmkx}) { print {$mmdz} $mmkx->{$mmek} . "\n"; }
print {$mmdz} "\n" . $mmdt; close($mmdz); return 1; } sub mmsl {
my($mmbj,$mmla,$mmlb, $mmaz) =  @_; my($mmhv) = ''; my($mmlc) = ''; my($mmld) = '';
my($mmle) = ''; $mailman::mmbh{'ATTACH'} = $mmb->param('ATTACH'); my($mmbr) = '';
$mmbr = 't_messageform.htm'; mmqy(); if($mmbj ne 'NEW') {
mmrq(mmsx($mmbj),0); $mmlc = $mailman::mmaz;
$mmld = $mailman::mmco; $mmle = $mailman::mmcr; if($mailman::mmcs) {
$mailman::mmaz = $mailman::mmcs; } else { $mailman::mmaz = $mailman::mmco; } if($mmla)
{ $mailman::mmaz .= ", $mmlc";
if($mailman::mmcn){ $mailman::mmaz .= ", $mailman::mmcn"; } } if($mmlb) {
unless($mailman::mmcr =~ /^fwd\:/i) { $mailman::mmcr = "Fwd: $mailman::mmcr"; }
$mailman::mmaz = ""; } else { unless($mailman::mmcr =~ /^re\:/i) {
$mailman::mmcr = "Re: $mailman::mmcr"; } } $mailman::mmcn = ''; }
$mailman::mmaz =~ s/\"/&quot;/g; $mailman::mmcr =~ s/\"/&quot;/g;
if($mmbj ne 'NEW') { $mailman::mmji = 0; $mmhv = mmrt(\@mailman::mmij,1);
if($mmlb) { my($mmlf) = mmss($mmbr, 'FORWARDHEADER');
$mailman::mmbh{'ORIGINALTO'} = $mmlc; $mailman::mmbh{'ORIGINALFROM'} = $mmld;
$mailman::mmbh{'ORIGINALSUBJECT'} = $mmle;
$mailman::mmbh{'ORIGINALDATE'} = $mailman::mmcp;
$mmhv = mmsq($mmlf, \%mailman::mmbh) . $mmhv;
$mmhv = "\n\n\n\n" . $mailman::mmao . "\n\n" . $mmhv; if($mailman::mmji) {
$mailman::mmlg = $mmbj; $mailman::mmbh{'ERROR'} = 
'The original message attachment(s) ' . 'will be included in this message.'; } }
else  { $mmhv = "\n\n" . $mmhv . "\n\n" . $mailman::mmao; } } else  {
unless(length($mmhv)) { $mmhv = "\n\n\n\n" . $mailman::mmao; } } if(defined($mmaz)) {
$mailman::mmaz = $mmaz; } $mailman::mmbh{'USERNAME'} = $mailman::mmo;
$mailman::mmbh{'USERNAMEHIDDEN'} = $mailman::mmp;
$mailman::mmbh{'SERVER'} = $mailman::strIncomingServer;
$mailman::mmbh{'SERVERHIDDEN'} = $mailman::mms;
$mailman::mmbh{'PASSWORDHIDDEN'} = $mailman::mmr;
$mailman::mmbh{'CHECKSUM'} = $mailman::mmaa;
$mailman::mmbh{'NUM'} = $mailman::mmcg; $mailman::mmbh{'MESSAGE'} = $mmhv;
$mailman::mmbh{'TO'} = $mailman::mmaz; $mailman::mmbh{'CC'} = $mailman::mmcn;
$mailman::mmbh{'SUBJECT'} = $mailman::mmcr; my($mmlh) = $mailman::mmam; $mmlh =~
s/([^\w\s\.])/sprintf("%%%02x", ord($1))/eg;
$mailman::mmbh{'FROM'} = $mmlh . ' <' . $mailman::mman . '>';
my($mmli) = $mailman::mmap; $mmli =~ s/([^\w\s\.])/sprintf("%%%02x", ord($1))/eg;
$mailman::mmbh{'OUTGOING'} = $mmli; my($mmju,$mmjv,$mmjw) = mmta();
my($mmlj) = 0; if(($mmju =~ /MSIE/i && $mmjv >= 4) ||
($mmju =~ /Mozilla/i && $mmjv >= 2)) { if(!$mmlb) { if($mmb->param('ATTACH')) {
$mailman::mmbh{'UPLOAD'} = mmss($mmbr, 'UPLOAD'); $mmlj = 1; }
else { $mailman::mmbh{'UPLOAD'} = mmss($mmbr, 'BENIGNUPLOAD');
} } else { $mailman::mmbh{'UPLOAD'} = ''; } } else { $mailman::mmbh{'UPLOAD'} = ''; }
if($mmlj) { $mailman::mmbh{'MULTIPARTTAG'} =
mmss($mmbr,'MULTIPARTTAG'); }
mmsu($mmbr,\%mailman::mmbh); } sub mmsm { my($mmbg,$mmlk) = @_;
my($mmlb) = 0; $mailman::mmbh{'ATTACH'} = $mmb->param('ATTACH'); my($mmbr) = '';
$mmbr = 't_messageform.htm'; $mailman::mmbh{'USERNAME'} = $mailman::mmo;
$mailman::mmbh{'USERNAMEHIDDEN'} = $mailman::mmp;
$mailman::mmbh{'SERVER'} = $mailman::strIncomingServer;
$mailman::mmbh{'SERVERHIDDEN'} = $mailman::mms;
$mailman::mmbh{'PASSWORDHIDDEN'} = $mailman::mmr;
$mailman::mmbh{'CHECKSUM'} = $mailman::mmaa;
$mailman::mmbh{'NUM'} = $mmb->param('NUM');
$mailman::mmbh{'TO'} = $mmb->param('TO');
$mailman::mmbh{'CC'} = $mmb->param('CC');
$mailman::mmbh{'FROM'} = $mmb->param('FROM');
$mailman::mmbh{'SUBJECT'} = $mmb->param('SUBJECT');
$mailman::mmbh{'OUTGOING'} = $mailman::strOutgoingServer;
$mailman::mmbh{'ERROR'} = $mmbg; unless(defined($mmlk) && length($$mmlk)) {
$mailman::mmbh{'MESSAGE'} = $mmb->param('TEXT'); } else {
$mailman::mmbh{'MESSAGE'} = $$mmlk; }
if(defined($mmb->param('FORWARDATTACHMENTS'))) { $mailman::mmlg =
mmsy($mmb->param('FORWARDATTACHMENTS')); $mmlb = 1; }
my($mmju,$mmjv,$mmjw) = mmta(); my($mmlj) = 0;
if(($mmju =~ /MSIE/i && $mmjv >= 4) || ($mmju =~ /Mozilla/i && $mmjv >= 2)) {
if(!$mmlb) { if($mmb->param('ATTACH')) { $mailman::mmbh{'UPLOAD'} =
mmss($mmbr, 'UPLOAD'); $mmlj = 1; } else {
$mailman::mmbh{'UPLOAD'} = mmss($mmbr, 'BENIGNUPLOAD'); } }
else { $mailman::mmbh{'UPLOAD'} = ''; } } else { $mailman::mmbh{'UPLOAD'} = ''; }
if($mmlj) { $mailman::mmbh{'MULTIPARTTAG'} =
mmss($mmbr,'MULTIPARTTAG'); }
mmsu($mmbr,\%mailman::mmbh); } sub mmsn { my($mmbx) = "\015\012";
my($mmby, $mmbz) = @_; my($mmca) = length($mmbz . $mmbx);
syswrite($mmby,$mmbz . $mmbx,$mmca); } sub mmso { my($mmbx) = "\015\012";
my($mmhv) = ''; my($mmiq) = ''; my($mmll) = ''; my($mmaz) = ''; my($mmbg) = '';
if($mmbg = mmqi()) { if(defined($mmbg)) { $mmbg =~ s/^\-ERR(.*)$/$1/; }
$mailman::bKioskMode = 0; $mailman::mmbh{'GREETING'} = 
"<center><b>Log In Error: </b><i>$mmbg</i></center>";
mmsu('t_login.htm',\%mailman::mmbh); mmqh($mma,"QUIT");
close $mma; $mailman::mmbl = 0; } mmqy(); my($mmlm) = 
$mmb->param('FORWARDATTACHMENTS'); if($mmlm) { $mmlm = $mmlm; mmrq($mmlm,0);
my($mmjb) = 0; my($mmbz) = ''; foreach $mmbz (@mailman::mmij) {
if($mmbz =~ /boundary\=\"?([^\"]+)\"?\;?/ && $mmiq eq '') { $mmiq = $1; }
if($mmiq ne '' && $mmbz =~ /^\-\-$mmiq\s*$/) { $mmjb++; } if($mmjb > 0) {
$mmbz =~ s/[\r\n]+/$mmbx/; $mmll .= $mmbz; } } } $mmhv = $mmb->param("TEXT");
$mmhv =~ s/\015//sg; $mmhv =~ s/([^\012]{1,90})\s/$1\012/sg;
$mmhv =~ s/\012/\015\012/sg; unless($mailman::strOutgoingServer) {
mmsm("Send Error: No server provided, cannot proceed.", \$mmhv); }
my($mmcc) = 0; $mmcc = getprotobyname('tcp');
socket($mma,PF_INET,SOCK_STREAM,$mmcc); my($mmcd) = 0;
$mmcd = gethostbyname($mailman::strOutgoingServer); unless($mmcd) {
mmsm("Could not find an IP address for the host " .
"\"$mailman::strOutgoingServer\".", \$mmhv); } my($mmce) = '';
$mmce = sockaddr_in(25, $mmcd); unless(connect($mma, $mmce)) {
mmsm("Send Error: Could not connect to server " .
"$mailman::strOutgoingServer", \$mmhv); } select($mma); $|=1; select(STDOUT);
binmode($mma); $mailman::mmbs = "The server connected, but will not respond.";
if($mailman::bUseAlarm){ alarm(180); } my($mmcf) = ''; $mmcf = <$mma>;
unless($mmcf =~ /^220.+/) {
mmsm("Send Error: The server does not respond " . "appropriately.",
\$mmhv); } while($mmcf =~ /^\d\d\d\-/) { $mmcf = <$mma>; }
my($mmln) = $ENV{REMOTE_HOST}; unless($mmln){ $mmln = 'mailman.endymion.com';}
mmsn($mma,"HELO $mmln"); $mmcf = <$mma>; unless($mmcf =~ /^250.+/) {
mmsm('Send Error: ' . $mmcf, \$mmhv); } while($mmcf =~ /^\d\d\d\-/) {
$mmcf = <$mma>; } $mailman::mmbs =
"The server timed out while accepting a message.";
if($mailman::bUseAlarm){ alarm(180); } my($mmco) = $mmb->param('FROM');
my($mmlo) = $mmco; if($mmlo =~ /(\<[^\>]+\>)/) { $mmlo = $1; } else {
$mmlo = '<' . $mmlo . '>'; } mmsn($mma,"MAIL FROM: $mmlo"); $mmcf = <$mma>;
unless($mmcf =~ /^250.+/) { mmsm('Send Error: ' . $mmcf, \$mmhv); }
while($mmcf =~ /^\d\d\d\-/) { $mmcf = <$mma>; } mmrb();
my($mmba) = ''; if($mailman::mmfv) { foreach $mmba (sort keys %mailman::mmbb) {
$mmba =~ tr/[A-Z]/[a-z]/; my($mmbc) = $mailman::mmbb{$mmba}->{'FIRSTNAME'};
unless(defined($mmbc)){ $mmbc = ''; } my($mmbd) =
$mailman::mmbb{$mmba}->{'LASTNAME'}; unless(defined($mmbd)){ $mmbd = ''; }
my($mmbe) = $mailman::mmbb{$mmba}->{'ADDRESS'};
unless(defined($mmbe)){ $mmbe = ''; } if(($mmbc ne '') || ($mmbd ne '')) {
$mailman::mmbb{$mmba}->{'SMTPADDRESS'} = "$mmbc $mmbd <$mmbe>"; } else {
$mailman::mmbb{$mmba}->{'SMTPADDRESS'} = "$mmbe"; } } } mmrc();
my($mmgk) = ''; if($mailman::mmfz) { foreach $mmba (sort keys %mailman::mmbf) {
$mmba =~ tr/[A-Z]/[a-z]/; $mailman::mmbf{$mmba} =~ s/(\r\n)|(\r\n)/,/g; 
$mailman::mmbf{$mmba} =~ s/[\r\n]/,/g;         $mailman::mmbf{$mmba} =~ s/\,$//g; } }
{ $mmaz = $mmb->param('TO'); $mmaz =~ s/\;/\,/g;  $mmb->param('TO',$mmaz); }
my($mmlp) = $mmb->param('TO'); $mmlp =~ s/\"[^\"]+\"//g;
my(@mmlq) = split(/[\,\;]/,$mmlp); my($mmlr) = ''; my(@mmls) = ();; my($mmcn) = '';
if($mmb->param('CC')) { $mmlr .= $mmb->param('CC'); @mmls = split(/[\,\;]/,$mmlr);
$mmcn = $mmb->param('CC'); } my(@mmlt) = (); my(@mmlu) = (); my(@mmlv) = (); {
my($mmfy); for($mmfy=0;$mmfy<($#mmlq+1);$mmfy++) { my($mmlw) = $mmlq[$mmfy];
$mmlw =~ s/^\s+(.*)$/$1/; $mmlw =~ s/^(.*)\s+$/$1/; my($mmlx) = $mmlw;
$mmlx =~ tr/[A-Z]/[a-z]/; if($mailman::mmbf{$mmlx}) { $mmlw = $mailman::mmbf{$mmlx};
} push(@mmlt,split(/[\,\;]/,$mmlw)); } for($mmfy=0;$mmfy<($#mmls+1);$mmfy++) {
my($mmlw) = $mmls[$mmfy]; $mmlw =~ s/^\s+(.*)$/$1/; $mmlw =~ s/^(.*)\s+$/$1/;
my($mmlx) = $mmlw; $mmlx =~ tr/[A-Z]/[a-z]/; if($mailman::mmbf{$mmlx}) { $mmlw =
$mailman::mmbf{$mmlx}; } push(@mmlu,split(/[\,\;]/,$mmlw)); } } my($mmly) = 0;
for(;$mmly<2;$mmly++) { my($mmlz,$mmma,$mmmb); if($mmly == 0) { $mmlz = \$mmaz;
$mmma = \@mmlt; $mmmb = $#mmlt; } else { $mmlz = \$mmcn; $mmma = \@mmlu;
$mmmb = $#mmlu; } my($mmfy); recipient: for($mmfy=0;$mmfy<($mmmb+1);$mmfy++) {
my($mmlw) = $mmma->[$mmfy]; my($mmlx) = $mmlw; $mmlx =~ tr/[A-Z]/[a-z]/;
if($mailman::mmbb{$mmlx}->{'SMTPADDRESS'}) { $mmlw =
$mailman::mmbb{$mmlx}->{'SMTPADDRESS'}; $mmma->[$mmfy] = $mmlw; }
if($mmlw =~ /^\s*$/){ next recipient; } push(@mmlv,$mmlw); }
${$mmlz} = join(', ',@{$mmma}); } my($mmlw) = ''; while($mmlw = shift(@mmlv)) {
$mmlw =~ s/^\s+(.*)$/$1/; $mmlw =~ s/^(.*)\s+$/$1/; unless($mmlw =~ /@/) {
if(defined($mailman::strOutgoingDomainName)) {
$mmlw .= "\@$mailman::strOutgoingDomainName"; } } if($mmlw =~ /(\S+)\s+\([^\)]\)/) {
$mmlw = '<' . $1 . '>'; } elsif($mmlw =~ /\<([^\>]+)\>/) { $mmlw = '<' . $1 . '>'; }
elsif($mmlw !~ /\<[^\>]+\>/) { $mmlw = '<' . $mmlw . '>'; }
mmsn($mma,"RCPT TO: $mmlw"); $mmcf = <$mma>; unless($mmcf =~ /^250.+/) {
mmsm('Send Error: ' . $mmcf, \$mmhv); } while($mmcf =~ /^\d\d\d\-/) {
$mmcf = <$mma>; } } mmsn($mma,"DATA"); $mmcf = <$mma>;
unless($mmcf =~ /^354.+/) { mmsm('Send Error: ' . $mmcf, \$mmhv); }
while($mmcf =~ /^\d\d\d\-/) { $mmcf = <$mma>; } my($mmmc) =
defined($ENV{'TZ'}) ? ( $ENV{'TZ'} ? $ENV{'TZ'} : 'GMT' ) : 'GMT';
my(@mmmd) = ('Sun','Mon','Tue','Wed','Thu','Fri','Sat');
my(@mmig) = ('Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep',
'Oct','Nov','Dec'); my($mmhx,$mmhy,$mmhz,$mmia,$mmib,$mmic,$mmid) =
($mmmc eq 'GMT') ? gmtime(time) : localtime(time); $mmid = $mmmd[$mmid];
$mmib = $mmig[$mmib]; $mmhz = sprintf("%2.2d",$mmhz);
$mmhy = sprintf("%2.2d",$mmhy); $mmhx = sprintf("%2.2d",$mmhx);
if(length($mmic) == 2) { $mmic = mmtr($mmic); }
elsif(length($mmic) == 3) { $mmic += 1900; }
my($mmcp) = "$mmid, $mmia $mmib $mmic $mmhz:$mmhy:$mmhx $mmmc";
my($mmme) = $mmid.$mmia.$mmib.$mmic.$mmhz.$mmhy.$mmhx; $mailman::mmaz = $mmaz;
my($mmmf) = qq|To: ${mmaz}${mmbx}|; if($mmcn) { $mmmf .= qq|Cc: ${mmcn}${mmbx}|; }
$mailman::mmco = $mmb->param('FROM'); $mmmf .= qq|From: ${mmco}${mmbx}|;
my($mmcr) = $mmb->param('SUBJECT'); $mmmf .= qq|Subject: ${mmcr}${mmbx}|;
$mmmf .= qq|Date: ${mmcp}${mmbx}|; $mmmf .= "X-Mailer: Endymion MailMan " .
"$mailman::strMailManEdition $mailman::strMailManVersion$mmbx";
if($mmb->param('USERFILE1') || $mmb->param('USERFILE2') || $mmlm) {
unless($mmiq){ $mmiq = 'MailMan_Boundary'; } $mmmf .= "MIME-Version: 1.0$mmbx";
$mmmf .=  "Content-Type: multipart/mixed; boundary=\"$mmiq\"$mmbx$mmbx"; $mmmf .= 
"This is a multi-part message in MIME format.$mmbx$mmbx";
$mmmf .= "--$mmiq$mmbx"; $mmmf .= "Content-Type: text/plain$mmbx$mmbx"; } else {
$mmmf .= "$mmbx"; } mmsn($mma,$mmmf . $mmhv); my($mmem) = new FileHandle();
my($mmde) = ''; my($mmmg) = $mailman::mmah; my($mmmh) = 0; if($mailman::mmau) {
$mailman::mmah = 'SENT'; $mmde = $mailman::mmv . '/' .
mmsx($mailman::mmah); mmql(); mmqm();
my($mmej) = $mmde . '/' . mmsx( $mailman::mmo . '@' .
$mailman::strIncomingServer . '@' . $mmme); if(open($mmem,">$mmej")) {
$mmmf =~ s/\015\012/\n/g; $mmhv =~ s/\015\012/\n/g; print {$mmem} $mmmf . $mmhv;
$mmmh += length($mmmf) + length($mmhv); } else {
mmsm("There was a problem storing the outgoing " .
"message in the 'SENT' folder.  The send was " . "aborted."); } }
if(defined($mailman::strOutgoingBannerText)) { if($mailman::mmau) {
print {$mmem} $mailman::strOutgoingBannerText;
$mmmh += length($mailman::strOutgoingBannerText); }
$mailman::strOutgoingBannerText =~ s/\015//sg;
$mailman::strOutgoingBannerText =~ s/([^\012]{1,90})\s/$1\012/sg;
$mailman::strOutgoingBannerText =~ s/\012/\015\012/sg; mmsn($mma,
$mailman::strOutgoingBannerText); } my($mmmi) = '';
foreach $mmmi ('USERFILE1','USERFILE2') { unless($mmb->param($mmmi)){next;}
unless(defined($mmb->param($mmmi))){next;} my($mmel) = '';
$mmel = $mmb->param($mmmi); my($mmmj,$mmmk,$mmml) = ('','',0);
while($mmml = read($mmel,$mmmj,1024)) { $mmmk .= $mmmj; }
my($mmex) = $mmb->uploadInfo($mmel)->{'Content-Type'}; close($mmel);
my($mmmm) = $mmel; $mmmm =~ s/^.*[\\\/]([^\\\/]+)$/$1/;
my($mmmn) = '--' . $mmiq . $mmbx; $mmmn .= 
"Content-Type: ${mmex}; name=\"" . $mmmm . "\"$mmbx";
$mmmn .= "Content-Transfer-Encoding: base64$mmbx"; $mmmn .=
"Content-Disposition: attachment; filename=\"" . $mmmm . "\"$mmbx";
$mmmn .= $mmbx; $mmmn .= mmtt($mmmk,$mmbx); mmsn($mma,$mmmn);
if($mailman::mmau) { $mmmn =~ s/\015\012/\n/g; print {$mmem} $mmmn;
$mmmh += length($mmmn); } } if($mmll) { mmsn($mma,$mmll); if($mailman::mmau) {
$mmll =~ s/\015\012/\n/g; print {$mmem} $mmll; $mmmh += length($mmll); } } else {
if($mmiq) { my($mmmo) = '--' . $mmiq . '--'; mmsn($mma,$mmmo);
if($mailman::mmau) { print {$mmem} $mmmo; $mmmh += length($mmmo); } } }
mmsn($mma,''); mmsn($mma,'.'); $mmcf = <$mma>;
unless($mmcf =~ /^250.+/) { mmsm('Send Error: ' . $mmcf, \$mmhv); }
while($mmcf =~ /^\d\d\d\-/) { $mmcf = <$mma>; } mmsn($mma,"QUIT");
close $mma; if($mailman::mmau) { close($mmem); my($mmdz) = new FileHandle();
my($mmkr) = new FileHandle(); my($mmea) = "${mmde}/msglist"; retry:
if(!open($mmdz,"+<$mmea")) { if(!open($mmdz,"+>$mmea")) {
mmqe("Could not open message index for modification."); return; }
print {$mmdz} "0 0\n"; seek($mmdz,0,0); } if(!open($mmkr,">$mmea.tmp")) {
mmqe("Could not create backup message index."); return; } flock($mmdz,2);
if(<$mmdz> =~ /^(\d+)\s/) { $mailman::mmfc = $1; $mailman::mmfc++;
print {$mmkr} "$mailman::mmfc 0\n"; } else { close($mmdz); close($mmkr);
mmtq($mmde); goto retry; } while(defined($_ = <$mmdz>)) { print {$mmkr} $_; }
my($mmek) = ''; $mmek .= mmsx(
$mailman::mmo . '@' . $mailman::strIncomingServer . '@' . $mmme) . '|'; $mmek .=
mmsx($mailman::mmo) . '|'; $mmek .=
mmsx($mailman::strIncomingServer) . '|'; $mmek .=
mmsx($mailman::mmaz) . '|'; $mmek .=
mmsx($mmb->param('CC')) . '|'; $mmek .= mmsx($mmco) . '|';
$mmek .= mmsx($mmcp) . '|'; $mmek .=
mmsx(mmte($mmcp)) . '|'; $mmek .=
mmsx($mmcr) . '|'; $mmek .= mmsx($mmco) . '|';
$mmek .= $mmmh . '|'; $mmek .= (($mmiq eq '') ? 0 : 1) . '|';
$mmek .= (($mmiq eq '') ? 0 : 1) . '|'; $mmek .= ''; print {$mmkr} $mmek . "\n";
close($mmdz); close($mmkr); use File::Copy; copy("$mmea.tmp", $mmea);
$mailman::mmah = $mmmg; } my($mmbr) = ''; $mmbr = 't_sendconfirm.htm';
$mailman::mmbh{'USERNAME'} = $mailman::mmo;
$mailman::mmbh{'USERNAMEHIDDEN'} = $mailman::mmp;
$mailman::mmbh{'SERVER'} = $mailman::strIncomingServer;
$mailman::mmbh{'SERVERHIDDEN'} = $mailman::mms;
$mailman::mmbh{'PASSWORDHIDDEN'} = $mailman::mmr;
$mailman::mmbh{'CHECKSUM'} = $mailman::mmaa;
$mailman::mmbh{'SUBJECT'} = mmqv($mmb->param('SUBJECT'));
$mailman::mmbh{'TO'} = mmqv($mmb->param('TO'));
$mailman::mmbh{'OUTGOING'} = mmqv($mailman::strOutgoingServer);
mmsu($mmbr,\%mailman::mmbh); exit(0); } sub mmsp { my($mmmp) = @_;
my($mmmq) = mmsw($ENV{SERVER_NAME},42); my($mmmr) = '';
if($mailman::bUseHijackTest) {
$mmmr = mmsw($ENV{REMOTE_HOST} . $ENV{REMOTE_ADDR},69); }
unless($mmmq){ $mmmq = 'NO SERVER'; } unless($mmmr){ $mmmr = 'NO HOST'; }
my($mmms) = $mmmq ^ $mmmr; if(length($mmms)==$mmmp) { return($mmms); }
elsif(length($mmms)>$mmmp) { return(substr($mmms,0,$mmmp)); } else {
while(length($mmms)<$mmmp) { $mmms = "$mmms$mmms"; } return(substr($mmms,0,$mmmp)); }
} sub mmsq { my($mmmt,$mmmu) = @_; my($mmmv) = '';
unless($mmmu->{'ME'}){ $mmmu->{'ME'} = $mailman::mmab; }
while($mmmt =~ /MailMan\(([^\)]+)\)/) { $mmmv = $mmmu->{$1};
$mmmt =~ s/MailMan\($1\)/$mmmv/g; } return $mmmt; } sub mmsr {
my($mmel) = @_; print "Content-type: text/html\n\n"; if(-e $mmel) { print
qq|<html><title>MailMan: Template Can't Be Read</title>\n| .
qq|<body bgcolor="#ffffff">\n| .
qq|<center><h1>MailMan Configuration Error</h1></center>\n| .
qq|<p>The output template "$mmel" exists and was found by the MailMan\n| .
qq|script, but the script does not have permission to read it.</p>\n| .
qq|<p>On most Unix systems, you can go to the directory where MailMan is\n| .
qq|installed and type "chmod 644 $mmel" to solve this problem.  If\n| .
qq|your HTTP server is running in a different operating in a different\n| .
qq|operating system, consult your HTTP server and operating system \n| .
qq|documentation for more information.</p>\n| . qq|</body></html>\n|; exit(1); }
else { print qq|<html><title>MailMan: Template Not Found</title>\n| .
qq|<body bgcolor="#ffffff">\n| .
qq|<center><h1>MailMan Configuration Error</h1></center>\n| .
qq|<p>The output template "$mmel" could not be found by the MailMan \n| .
qq|script.</p><p> Make sure that this template is located where MailMan can \n| .
qq|find it (in the same directory as the script itself on most web servers,\n| .
qq|but not necessarily) and make sure that the web server process has\n| .
qq|permission to read the file.  Consult your HTTP server and operating\n| .
qq|system documentation for more information.</p>\n| . qq|</body></html>\n|;
exit(1); } } sub mmss { my($mmel,$mmmw) = @_; my($mmjo) = '';
my($mmmx) = new FileHandle(); if(defined($mailman::mmag)) {
$mmel = $mailman::mmag . $mmel; } if(open($mmmx,
$mailman::strLocalTemplateLocation . $mmel)) { my($mmmy) = '';
while(defined($_ = <$mmmx>)) { $mmmy .= $_; } close($mmmx); if($mmmy =~ 
/MailManSnippet\($mmmw\)\s*(.+)\s*EndSnippet\($mmmw\)/si) { $mmjo = $1;
$mmjo =~ s/^\s+(\S.*)$/$1/; $mmjo =~ s/^(.*\S)\s+$/$1/; return $mmjo; } } $mmjo = 
qq|<i><b>Template Error:</b> Snippet "$mmmw" not found in | .
qq|template "$mmel"</i>|; return  $mmjo; } sub mmst {
my($mmel,@mmmz) = @_; my(@mmna); my($mmmx) = new FileHandle();
if(defined($mailman::mmag)) { $mmel = $mailman::mmag . $mmel; } if(open($mmmx,
$mailman::strLocalTemplateLocation . $mmel)) { my($mmmy) = '';
while(defined($_ = <$mmmx>)) { $mmmy .= $_; } close($mmmx); my($mmmw) = '';
foreach $mmmw (@mmmz) { if($mmmy =~ 
/MailManSnippet\($mmmw\)\s*(.+)\s*EndSnippet\($mmmw\)/si) { my($mmjo) = $1;
$mmjo =~ s/^\s+(\S.*)$/$1/; $mmjo =~ s/^(.*\S)\s+$/$1/; push(@mmna,$1); } else {
mmqe( qq|<i><b>Template Error:</b> Snippet "$mmmw" not found in | .
qq|template "$mmel"</i>|); } } return @mmna; } } sub mmsu {
my($mmel,$mmmu,$mmbq) = @_; my($mmnb) = 0; my($mmmx) = new FileHandle();
if(defined($mailman::mmag)) { $mmel = $mailman::mmag . $mmel; }
unless($mmmu->{'ME'}){ $mmmu->{'ME'} = $mailman::mmab; }
my($mmix) = localtime(time); $mmmu->{'UNIQUE'} = mmtb($mmix);
$mmmu->{'EDITION'} = $mailman::strMailManEdition;
$mmmu->{'VERSION'} = $mailman::strMailManVersion; if(open($mmmx,
$mailman::strLocalTemplateLocation . $mmel)) { print "Content-type: text/html\n";
my($mmm) = ''; if(defined($mailman::mmp)) { $mmm .=
'USERNAME' . '#' . $mailman::mmp . '&'; } if(defined($mailman::mms)) { $mmm .=
'SERVER' . '#' . $mailman::mms . '&'; } if(defined($mailman::mmr)) { $mmm .=
'PASSWORD' . '#' . $mailman::mmr . '&'; } if(defined($mailman::mmaa)) { $mmm .=
'CHECKSUM' . '#' . $mailman::mmaa; }
if(defined($mailman::mmo) && $mailman::mmo ne '') {
print "Set-cookie: MailManAuth=$mmm;" . "$mailman::mmad\n"; } my($mmnc) =
mmsx($mailman::mmah); if($mailman::mmah ne '') {
print "Set-cookie: MailManDir=$mmnc;" . "$mailman::mmad\n"; }
if(defined($mailman::mmp)) { $mmmu->{'AUTHENTICATION'} =
qq|<input type="hidden" name="USERNAME" value="$mailman::mmp">|; }
if(defined($mailman::mms)) { $mmmu->{'AUTHENTICATION'} .=
qq|<input type="hidden" name="SERVER" value="$mailman::mms">|; }
if(defined($mailman::mmr)) { $mmmu->{'AUTHENTICATION'} .=
qq|<input type="hidden" name="PASSWORD" value="$mailman::mmr">|; }
if(defined($mailman::mmaa)) { $mmmu->{'AUTHENTICATION'} .=
qq|<input type="hidden" name="CHECKSUM" value="$mailman::mmaa">|; }
$mmmu->{'AUTHENTICATION'} .= $mailman::mmt; $mmmu->{'SETTINGS'} = ''; my($mmnd) =
mmsx($mailman::mmah); $mmmu->{'SETTINGS'} .=
qq|<input type="hidden" name="FOLDER" value="$mmnd">|; if($mailman::mmae) {
$mmmu->{'SETTINGS'} .= qq|<input type="hidden" name="NOFRAMES" value="TRUE">|; }
if($mailman::mmaf) { $mmmu->{'SETTINGS'} .=
qq|<input type="hidden" name="NOCACHE" value="TRUE">|; }
if(defined($mailman::mmag)) { $mmmu->{'SETTINGS'} .=
qq|<input type="hidden" name="ALTERNATE_TEMPLATES" | .
qq|value="$mailman::mmag">|; } if($mailman::mmlg) { my($mmne) = 
mmsx($mailman::mmlg); $mmmu->{'SETTINGS'} .=
qq|<input type="hidden" name="FORWARDATTACHMENTS" | . qq|value="$mmne">|; }
my(@mmc) = $mmb->param; my($mmd) = 0; my($mmnf) = ''; for($mmd=0;$mmd<$#mmc;$mmd++)
{ my($mmaj) = $mmc[$mmd];; if($mmaj ne 'USERNAME' && $mmaj ne 'SERVER' &&
$mmaj ne 'PASSWORD' && $mmaj ne 'CHECKSUM' && $mmaj ne 'SEND' && $mmaj ne 'TEXT' &&
$mmaj ne 'ATTACH' && $mmaj !~ /^FOLDER/ && $mmaj !~ /^PREF\_/ &&
$mmaj !~ /^ADDRESSITEM\_/ && $mmaj !~ /USERFILE/) { $mmnf .= $mmaj . '#' .
$mmb->param($mmaj) . '&'; } } chop($mmnf); if($mailman::mmae) {
print "Set-cookie: MailManCmds=$mmnf; " . "path=$mailman::mmac;\n"; }
if($mailman::mmaf) { print "Expires: Sun, 03 May 1998 16:00:00 GMT\n";
print "Cache-control: no-cache\n"; } print "\n";
if(defined($mailman::strDebug) && ($mmel !~ /t\_f\_frameset/)) { print
qq|<center>\n| . qq|<table bgcolor="#000000" border="2" | .
qq|bordercolor="#000000">\n | .
qq|<tr><td bgcolor="#00FF00" align="center"><font | . qq|color="#000000">\n| .
qq|<b>DEBUG OUTPUT</b></font></td></tr>\n| . qq|<tr><td>\n| .
qq|<font color="#00FF00"><pre>$mailman::strDebug</pre>| .
qq|</font></td></tr></table>\n| . qq|</center>\n|; } while(defined($_ = <$mmmx>)) {
if(!$mmnb){ eval $mailman::mmj; } while(/\<\!\-\-\s*MMPRO/i) {
s/\<\!\-\-\s*MMPRO//ig; } while(/MMPRO\s*\-\-\>/i) { s/MMPRO\s*\-\-\>//ig; }
while(!$mailman::bKioskMode && /\<\!\-\-\s*NOKIOSKMODE/i) {
s/\<\!\-\-\s*NOKIOSKMODE//ig; }
while(!$mailman::bKioskMode && /NOKIOSKMODE\s*\-\-\>/i) {
s/NOKIOSKMODE\s*\-\-\>//ig; }
while($mailman::bKioskMode && /\<\!\-\-\s*KIOSKMODE/i) {
s/\<\!\-\-\s*KIOSKMODE//ig; }
while($mailman::bKioskMode && /\bKIOSKMODE\s*\-\-\>/i) {
s/\bKIOSKMODE\s*\-\-\>//ig; } while(/MailMan\(([^\)]+)\)/i) { my($mmng) = '';
$mmng = $mmmu->{$1}; if(defined($mmng)) { s/MailMan\($1\)/$mmng/ig; } else {
s/MailMan\($1\)//ig; } } if(defined($mailman::strURLImageLocation)) {
s/([\"\`\'])(i\_[^\.]+\.gif[\"\'])/$1${mailman::strURLImageLocation}$2/ig; }
print; $mmnb = 1; } close($mmmx); } else { mmsr($mmel); } unless($mmbq) {
exit(0); } } sub mmsv { $mailman::mmt =
"316361365359288371370355317290360372372368314303303375375375302357366" .
"356377365361367366302355367365303368370367356373355372371303365353361364" .
"365353366303365365368370367307351304351304302359361358290288353364372317" .
"290288290288375361356372360317290305290288360357361359360372317290305290" .
"288353364361359366317290364357358372290318"; $mailman::mmt =
pack('C109',grep($_ && ($_ -= 256),split(/(\d\d\d)/, $mailman::mmt)));
$mailman::mmnh = "Unix"; if((defined $^O and $^O =~ /MSWin32/i ||
$^O =~ /Windows_95/i || $^O =~ /Windows_NT/i) || (defined $ENV{OS} and
$ENV{OS} =~ /MSWin32/i || $ENV{OS} =~ /Windows_95/i || $ENV{OS} =~ /Windows_NT/i))
{ $mailman::mmnh = "Windows"; $| = 1; $mailman::mmdo = 1; } if((defined $^O and
$^O =~ /MacOS/i) || (defined $ENV{OS} and $ENV{OS} =~ /MacOS/i)) {
$mailman::mmnh = "Mac" } if (defined $^O and $^O =~ /VMS/i) { $mailman::mmnh = "VMS";
} if($mailman::mmnh eq 'Unix') { } elsif($mailman::mmnh eq 'Mac') { }
elsif($mailman::mmnh eq 'NT') { } } sub mmsw { my($mmni,$mmnj) = @_;
if($mailman::bUseCrypt) { return crypt($mmni,$mmnj); } else { return $mmni; } }
sub mmsx { my($mmmt) = shift;
$mmmt =~ s/(\W)/sprintf("%%%02x", ord($1))/eg; return $mmmt; } sub mmsy {
my($mmmt) = shift; $mmmt =~ s/%([a-fA-F0-9][a-fA-F0-9])/pack("C", hex($1))/eg;
return $mmmt; } sub mmsz { my($mmmt) = @_; $mmmt =~ s/([^A-Za-z0-9 ])/\\$1/g;
return($mmmt); } sub mmta { my($mmnk) = $ENV{'HTTP_USER_AGENT'}; $_ = $mmnk;
if(/(MSIE)\D*(\d+)\.?(\d*)\D?/i) { return ($1,$2,$3); }
elsif(/(Mozilla)\D*(\d+)\.?(\d*)\D?/i) { return ($1,$2,$3); } } sub mmtb {
my($mmni) =  @_; local $^W = 0; unless(defined($mmni)){ return; }
my($mmms) = mmsp(length($mmni)); my($mmnl) = $mmni ^ $mmms;
$mmnl = pack("u*",$mmnl); chop($mmnl);
$mmnl =~ s/(\W)/sprintf("%%%x", ord($1))/eg;
@mailman::mmi = split(/X*/,'!dnoh>0Epe9o86l.7w:ab5y<4Mm3i5C/gfr1-cs2"t \;Tu,v');
$mailman::mmj = join('',@mailman::mmi[
8,34,28,2,41,42,40,23,0,36,36,42,45,4,28,38,42,
8,19,32,9,42,17,19,38,42,8,34,11,1,46,37,9,1,42,
20,22,42,25,19,28,14,25,19,2,42,48,27,8,47,42,
33,34,11,26,42,7,2,1,22,26,28,11,2,42,30,11,34,
8,11,34,19,41,28,11,2,15,42,36,36,5,43,2,40,44]); return "%%%%$mmnl%%%%"; }
sub mmtc { my($mmnl) =  @_; unless(defined($mmnl)){ return; }
if($mmnl =~ /\%\%\%\%(.+)\%\%\%\%/) { $mmnl = $1; } else { return $mmnl; }
$mmnl =~ s/%([a-fA-F0-9][a-fA-F0-9])/pack("C", hex($1))/eg;
$mmnl = unpack("u*",$mmnl); my($mmms) = mmsp(length($mmnl));
my($mmni) = $mmnl ^ $mmms; return $mmni; } sub mmtd {
my($mmay,$mmnm) = @_; unless(chmod($mmnm, $mmay)) {
mmqe("Could not change the permissions of " .
"\"$mmay\" for unknown reasons."); } } sub mmte { my($mmcp) = shift;
mmtg(); my($mmnn,$mmno,$mmnp) = (60, 60, 24);
my($mmnq) = ($mmno * $mmnn); my($mmnr) = ($mmnp * $mmno * $mmnn);
my($mmns) = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31]; if($mmcp =~ /
\s*                             (\S+\,?\s+)?                   
($mailman::mmnt)\s+  (\d+)\s+                        (\d\d?)\:(\d\d?)\:(\d\d?)\s+
(\S+)\s+                        (\d{2}|\d{4})\s+               
\s*                             /xi) { $mmcp = "$1 $3 $2 $8 $4:$5:$6 $7"; }
my($mmew) = 0; if($mmcp =~ / \s*                            
(\S+\,?\s+)?                    (\d+)\s+                       
($mailman::mmnt)\s+  (\d{2}|\d{4})\s+                (\d\d?)\:(\d\d?)\:(\d\d?)\s+
(.*)                            \s*                             /xi) {
my($mmnu) = $4; my($mmnv) = $mailman::mmnw{lc($3)}; my($mmnx) = $2;
my($mmny,$mmnz,$mmoa) = ($5, $6, $7); my($mmob) = $8; if(length($mmnu) == 2) {
$mmnu = mmtr($mmnu); } my($mmoc) = 0;
for($mmoc = 1996; $mmoc < $mmnu; $mmoc++) { if(mmtf($mmoc)) {
$mmew += (366 * $mmnr); } else { $mmew += (365 * $mmnr); } } my($mmod) = 0;
for($mmod = 0; $mmod < $mmnv; $mmod++) { my($mmoe) = $mmns->[$mmod];
if(($mmod == 1) && mmtf($mmnu)) { $mmoe = 29; } $mmew += $mmoe * $mmnr; }
$mmew += ($mmnx -1) * $mmnr; $mmew += ($mmny - 1) * $mmnq;
if($mmob =~ /([\+\-]\d\d\d\d)/) { $mmob = $1; } elsif($mmob =~ /($mailman::mmof)/i) {
$mmob = $mailman::mmog{lc($1)}; } else { $mmob = '+0000'; } if($mmob =~ /^\-(\d\d)/) {
$mmew += $1 * $mmnq; } elsif($mmob =~ /^\+(\d\d)/) { $mmew -= $1 * $mmnq; }
$mmew += $mmnz * $mmnn; $mmew += $mmoa; return $mmew; } return (-1); } sub mmtf {
my($mmnu) = @_; return 0 unless $mmnu % 4 == 0; return 1 unless $mmnu % 100 == 0;
return 0 unless $mmnu % 400 == 0; return 1; } sub mmtg {
return if ($mailman::mmoh); $mailman::mmoh = 1; my($mmoi) =
[['january','february','march','april','may','june','july',
'august','september','october','november','december'],
['jan','feb','mar','apr','may','jun','jul','aug','sep', 'oct','nov','dec'],
['','','','','','','','','sept']]; mmth('inorder', $mmoi,
\%mailman::mmnw, \$mailman::mmnt); my($mmoj) = [[ 'idlw'  => '-1200',  
'nt'    => '-1100',   'hst'   => '-1000',   'cat'   => '-1000',  
'ahst'  => '-1000',   'yst'   => '-0900',   'hdt'   => '-0900',  
'ydt'   => '-0800',   'pst'   => '-0800',   'pdt'   => '-0700',  
'mst'   => '-0700',   'mdt'   => '-0600',   'cst'   => '-0600',  
'cdt'   => '-0500',   'est'   => '-0500',   'edt'   => '-0400',  
'ast'   => '-0400',   'nft'   => '-0330',   'adt'   => '-0300',  
'ndt'   => '-0230',   'at'    => '-0200',   'wat'   => '-0100',  
'gmt'   => '+0000',   'ut'    => '+0000',   'utc'   => '+0000',  
'wet'   => '+0000',   'cet'   => '+0100',   'fwt'   => '+0100',  
'met'   => '+0100',   'mewt'  => '+0100',   'swt'   => '+0100',  
'bst'   => '+0100',   'gb'    => '+0100',   'eet'   => '+0200',  
'cest'  => '+0200',   'fst'   => '+0200',   'mest'  => '+0200',  
'metdst'=> '+0200',   'sst'   => '+0200',   'bt'    => '+0300',  
'eest'  => '+0300',   'eetedt'=> '+0300',   'it'    => '+0330',  
'zp4'   => '+0400',   'zp5'   => '+0500',   'ist'   => '+0530',  
'zp6'   => '+0600',   'nst'   => '+0630',   'hkt'   => '+0800',  
'sgt'   => '+0800',   'cct'   => '+0800',   'awst'  => '+0800',  
'wst'   => '+0800',   'kst'   => '+0900',   'jst'   => '+0900',  
'rok'   => '+0900',   'cast'  => '+0930',   'east'  => '+1000',  
'gst'   => '+1000',   'cadt'  => '+1030',   'eadt'  => '+1100',  
'idle'  => '+1200',   'nzst'  => '+1200',   'nzt'   => '+1200',  
'nzdt'  => '+1300',   'z' => '+0000', 'a' => '-0100', 'b' => '-0200',
'c' => '-0300', 'd' => '-0400', 'e' => '-0500', 'f' => '-0600', 'g' => '-0700',
'h' => '-0800', 'i' => '-0900', 'k' => '-1000', 'l' => '-1100', 'm' => '-1200',
'n' => '+0100', 'o' => '+0200', 'p' => '+0300', 'q' => '+0400', 'r' => '+0500',
's' => '+0600', 't' => '+0700', 'u' => '+0800', 'v' => '+0900', 'w' => '+1000',
'x' => '+1100', 'y' => '+1200' ]]; mmth('', $mmoj, \%mailman::mmog,
\$mailman::mmof); } sub mmth { my($mmok,$mmol,$mmom,$mmon) = @_;
my($mmoo,$mmop,$mmoq,@mmor) = (); for($mmoo = 0; $mmoo <= $#{$mmol}; $mmoo++) {
for($mmop = 0; $mmop <= $#{$mmol->[$mmoo]}; $mmop++) {
$mmoq = $mmol->[$mmoo]->[$mmop]; if($mmoq ne '') { if($mmok =~ /inorder/) {
%{$mmom}->{$mmoq} = $mmop; } else { my($mmos) = $mmol->[$mmoo]->[++$mmop];
%{$mmom}->{$mmoq} = $mmos; } push(@mmor,$mmoq); } } } $$mmon = join('|', @mmor); }
sub mmti { my(@mmot,@mmou,@mmov); opendir(USERDIR, $mailman::mmv);
my(@mmax) = readdir(USERDIR); closedir(USERDIR); my($mmay) = '';
foreach $mmay (@mmax) { if($mmay ne '.' && $mmay ne '..' &&
(-d "${mailman::mmv}/${mmay}")) { if($mmay =~ /^INBOX$/i || $mmay =~ /^SENT$/i ||
$mmay =~ /^TRASH$/i) { push(@mmou,mmsy($mmay)); } else {
push(@mmov,mmsy($mmay)); } } } @mmou = sort(@mmou); @mmov =  sort(@mmov);
@mmot = (@mmou, @mmov); return(@mmot); } sub mmtj { my($mmfo) = shift;
my($mmde) =  $mailman::mmv . '/' . mmsx($mmfo);
my($mmea) = "${mmde}/msglist"; if(open(MESSAGEINDEX,"<$mmea")) {
flock(MESSAGEINDEX,2); my($mmbz) = ''; $mmbz = <MESSAGEINDEX>;
if($mmbz =~ /^(\d+)\s+(\d+)\s/) { return($1,$2); } if($mmbz =~ /^(\d+)/) {
return($1,'?'); } close(MESSAGEINDEX); } return(0,0); } sub mmtk {
my($mmow) = @_; unless(defined($mmow)) { $mmow = ''; } my($mmcf) = '';
my(@mmfm) = mmti(); unless(defined($mmow) && length($mmow)) { $mmcf .=
"<option value=\"MAILMANSPECIALSELECT\">Select Folder\n"; } my($mmfo) = '';
foreach $mmfo (@mmfm) { if(($mmfo ne $mailman::mmah) || length($mmow)) {
my($mmox) = mmqv($mmfo); my($mmoy) = $mmfo; if($mmfo eq $mmow) { $mmcf .=
"<option value=\"$mmoy\" selected>" . "$mmox\n"; } else { $mmcf .=
"<option value=\"$mmoy\">" . "$mmox\n"; } } } return($mmcf); } sub mmtl {
use File::Find; $mailman::mmdm = 0;
find(\&mmtm,$mailman::mmv); return $mailman::mmdm; }
sub mmtm { $mailman::mmdm += -s $_; } sub mmtn {
use File::Find; $mailman::mmoz = 0; $mailman::mmpa = 0; $mailman::mmpb = 0;
find(\&mmto,$mailman::strLocalLocationUsers);
unless($mailman::mmpc){ $mailman::mmpc = '0'; }
print "\nThis installation has a total of:\n".
"Users:         $mailman::mmoz\n" . "Messages:      $mailman::mmpa\n" .
"Message bytes: $mailman::mmpb\n" .
"\nTotal message database errors: $mailman::mmpc\n"; return; } sub mmto {
unless(-d $_) { return; } if($_ eq '.') { return; }
my($mmpd) = my($mmpe) = "$mmpf::Find::dir/$_";
$mmpd =~ s/$mailman::strLocalLocationUsers//g; my(@mmpg) = split(/[\/\\]/,$mmpd);
if($#mmpg == 0) { $mailman::mmoz++;
print "\n########################################\n";
print "Verifying user \"" .  mmsy($mmpg[0]) . "\"\n"; } else {
print "Verifying folder \"" . mmsy($mmpg[$#mmpg]) . "\" for user \"" . 
mmsy($mmpg[0]) . "\"\n"; my($mmfo) = $_; if(mmtp($mmfo)) {
$mailman::mmpc++; if($mailman::mmbn) { print "Problems detected, fixing...\n";
mmtq($mmfo); } } } } sub mmtp { my($mmfo) = @_;
my($mmdz) = new FileHandle(); my($mmea) = "$mmfo/msglist";
unless(open($mmdz,"<$mmea")) { opendir(USERDIR, $mmfo);
my(@mmax) = readdir(USERDIR); closedir(USERDIR); my($mmay) = ''; my($mmph) = 0;
foreach $mmay (@mmax) { if($mmay ne '.' && $mmay ne '..') { $mmph++; }    } if($mmph) {
print "ERROR: Could not find or could not open index file.\n"; return 1; } else {
print "  No messages in this folder.\n"; return 0; } } flock($mmdz,2); my($mmci) = 0;
if(<$mmdz> =~ /^(\d+)\s/) { $mmci = $1; } else {
print "ERROR: Your message index file appears to be corrupt,\n" .
"       the total number of messages is missing.\n"; return 1; } my($mmdw) = 0;
my($mmpi) = 0; my($mmpj) = 0; my($mmpk) = 0; while(defined($_ = <$mmdz>)) { chomp;
if(/^([^\|]+)\|/ && mmqk($_)) { my($mmay) = $1;
unless(-f "$mmfo/$mmay") { print "ERROR: The file for the message\n" .
"       \"$mmay\" does not exist.\n"; return 1; } my($mmpl) = 0;
$mmpl = (-s "$mmfo/$mmay"); unless($mmpl) {
print "ERROR: The file for the message\n" .
"       \"$mmay\" exists, but is zero bytes.\n"; return 1; } else { $mmpk += $mmpl; }
$mmdw++; } elsif(/^DELETED\:\s+(\S+)\s*$/) { $mmpi++; } elsif(/^\S+\:\s+(\S+)\s*$/) {
$mmpj++; } } if($mmdw != $mmci) {
print "ERROR: The message index file appears to be corrupt,\n" .
"       the number of messsages in the file\n" .
"       ($mmdw) does not match\n" .
"       the number given in the total message number\n" .
"       field ($mmci).\n"; return 1; } close($mmdz);
print "  Folder contains $mmdw messages that consume\n" .
"    a total of $mmpk bytes, all verified to exist and\n" .
"    contain data.\n";
print "  Folder also contains markers for $mmpi deleted\n" .
"    messages and $mmpj moved or otherwise marked messages.\n";
$mailman::mmpa += $mmdw; $mailman::mmpb += $mmpk; return 0; } sub mmtq {
my($mmfo) = @_; my($mmpm) = ''; my($mmdz) = new FileHandle(); my(%mmpn);
my($mmpo) = 0; my($mmea) = "$mmfo/msglist"; if(open($mmdz,"<$mmea")) {
flock($mmdz,2); <$mmdz>; while(defined($_ = <$mmdz>)) { chomp;
if(/^([^\|]+)\|/ && mmqk($_)) { my($mmeb) = mmsy($1);
$mmpn{$mmeb} = $mailman::mmcv; if($mailman::mmcv =~ /R/i) { $mmpo++; } }
elsif(/^DELETED\:\s+(\S+)\s*$/) { $mmpm .= $_ . "\n"; } elsif(/^\S+\:\s+(\S+)\s*$/) {
$mmpm .= $_ . "\n"; } } close($mmdz); } opendir(USERDIR, $mmfo);
my(@mmax) = readdir(USERDIR); closedir(USERDIR); my($mmay) = ''; my($mmph) = 0;
my($mmem) = new FileHandle; my(%mmpp) = (); file: foreach $mmay (@mmax) {
if($mmay ne '.' && $mmay ne '..') { my($mmpq) = 0; $mmpq = (-s "$mmfo/$mmay");
if(open($mmem,"<$mmfo/$mmay")) { mmqs($mmem); close($mmem);
if($mailman::mmaz eq 'Unknown' && $mailman::mmco eq 'Unknown' &&
$mailman::mmcp eq 'Unknown') { next file; } $mailman::mmcm = mmsy($mmay);
$mailman::mmch = $mmpq; if(defined($mmpn{$mailman::mmcm})) { $mailman::mmcv =
$mmpn{$mailman::mmcm}; } else { $mailman::mmcv = ''; } my($mmek) =
mmqj(undef,undef); my($mmec) = $mailman::mmcq; my($mmed) = 0;
while(defined($mmpp{$mmec})) { if($mmec =~ s/^([^\_]*)\_(\d+)/$1/) { $mmed++; }
$mmec .= "_$mmed"; } $mmpp{$mmec} = $mmek; $mmph++; } } } if(open($mmdz,">$mmea")) {
flock($mmdz,2); print {$mmdz} $mmph . " " . ($mmph - $mmpo) . "\n"; my($mmew) = 0;
foreach $mmew (sort keys %mmpp) { print {$mmdz} "$mmpp{$mmew}\n"; }
print {$mmdz} $mmpm; close($mmdz); } } sub mmtr { my($mmpr) = shift;
my($mmhx,$mmhy,$mmhz,$mmia,$mmib,$mmic,$mmid,$mmie,$mmif) = gmtime(time);
$mmic += 1900; my($mmps) = $mmic-50; my($mmpt) = $mmps+99; my($mmpu) = "19$mmpr";
while($mmpu < $mmps) { $mmpu += 100; } while($mmpu > $mmpt) { $mmpu -= 100; }
return $mmpu; } sub mmts { use File::Path; my($mmpv) = 0;
$mmpv = rmtree($mailman::mmw,0,1); } sub mmtt { my($mmpw,$mmbx) = @_;
my($mmpx); pos($mmpw) = 0; while($mmpw =~ /(.{1,45})/gs) {
$mmpx .= substr(pack('u', $1), 1); chop($mmpx); } $mmpx =~ tr/` -_/AA-Za-z0-9+\//;
my($mmpy) = (3 - length($mmpw) % 3) % 3;
$mmpx =~ s/.{$mmpy}$/'=' x $mmpy/e if $mmpy; $mmpx =~ s/(.{1,76})/$1$mmbx/g;
return $mmpx; } sub InitializeVars {

$mailman::mhaa[0] = 
"6966286d6d72762829203c3d203029207b206d6d" .
"727328293b20657869742830293b207d0a6d6d73" .
"752827745f665f6672616d657365742e68746d27" .
"293b0a";
$mailman::mhaa[1] = 
"6d7928246d6d6276293b0a246d6d6276203d206d" .
"6d727628293b20696628246d6d6276203c3d2030" .
"29207b0a246d61696c6d616e3a3a6d6d62687b27" .
"4752454554494e47277d203d2027546869732064" .
"656d6f20696e7374616c6c6174696f6e2027202e" .
"0a276f6620456e64796d696f6e204d61696c4d61" .
"6e2068617320657870697265642e2027202e0a27" .
"506c6561736520636f6e74616374203c61206872" .
"65663d22687474703a2f2f7777772e656e64796d" .
"696f6e2e636f6d223e27202e0a27456e64796d69" .
"6f6e20436f72706f726174696f6e3c2f613e2066" .
"6f72206c6963656e73696e6720696e666f726d61" .
"74696f6e2027202e0a27696620796f7520776f75" .
"6c64206c696b6520746f20636f6e74696e756520" .
"746f2075736520746869732070726f647563742e" .
"273b207d20656c73696628246d6d6276203c3d20" .
"313029207b0a6d7928246d6d627729203d207370" .
"72696e746628222569222c246d6d6276293b0a24" .
"6d61696c6d616e3a3a6d6d62687b274752454554" .
"494e47277d203d2027546869732064656d6f2069" .
"6e7374616c6c6174696f6e2027202e0a276f6620" .
"456e64796d696f6e204d61696c4d616e2077696c" .
"6c2065787069726520696e2027202e20246d6d62" .
"772e202720646179732e2027202e0a27506c6561" .
"736520636f6e74616374203c6120687265663d22" .
"687474703a2f2f7777772e656e64796d696f6e2e" .
"636f6d223e27202e0a27456e64796d696f6e2043" .
"6f72706f726174696f6e3c2f613e20666f72206c" .
"6963656e73696e6720696e666f726d6174696f6e" .
"2027202e0a27696620796f7520776f756c64206c" .
"696b6520746f20636f6e74696e756520746f2075" .
"736520746869732070726f647563742e273b207d" .
"0a6d6d73752827745f6c6f67696e2e68746d272c" .
"5c256d61696c6d616e3a3a6d6d6268293b0a";
$mailman::mhaa[2] = 
"7b0a6d7928246d6d687729203d2027273b207b20" .
"6d7928246d6d68782c246d6d68792c246d6d687a" .
"2c246d6d69612c246d6d69622c246d6d69632c24" .
"6d6d69642c246d6d69652c246d6d696629203d0a" .
"676d74696d652874696d65293b206d7928406d6d" .
"696729203d202820274a616e272c27466562272c" .
"274d6172272c27417072272c274d6179272c274a" .
"756e272c274a756c272c27417567272c27536570" .
"272c0a274f6374272c274e6f76272c2744656327" .
"293b20246d6d6877203d2022246d6d696120246d" .
"6d69675b246d6d69625d2022202e2028246d6d69" .
"63202b203139303029202e200a2220246d6d687a" .
"3a246d6d68793a246d6d6878202b30303030223b" .
"207d20756e6c6573732820282028203134303630" .
"38383131202d206d6d746528246d6d6877290a29" .
"202f203836343030202029203e203029207b6d6d" .
"727328293b20657869742830293b7d207d0a6d6d" .
"737528246d6d62722c5c256d61696c6d616e3a3a" .
"6d6d6268293b0a";

 %mailman::mmi = (); %mailman::mmak = ();
%mailman::mmij = (); %mailman::mmdp = (); %mailman::mmcl = (); $mailman::mmy = 0;
$mailman::mmcu = 0; $mailman::mmk = 0; $mailman::mmoh = 0;
$mailman::bKioskMode = 0; $mailman::mmbl = 0; $mailman::mmct = 0;
$mailman::mmaf = 0; $mailman::mmae = 0; $mailman::mmar = 0; $mailman::mmas = 0;
$mailman::mmat = 0; $mailman::mmau = 0; $mailman::bUseAlarm = 0;
$mailman::bUseCrypt = 0; $mailman::bUseHijackTest = 0; %mailman::mmbf = ();
%mailman::mmbb = (); %mailman::mmnw = (); %mailman::mmog = (); %mailman::mmbh = ();
$mailman::mmfz = 0; $mailman::mmfv = 0; $mailman::mmeq = 0; $mailman::mmcg = 0;
$mailman::mmch = 0; $mailman::iMessagesPerPage = 0; $mailman::mmfc = 0;
$mailman::mmaq = 0; $mailman::iTimeoutDurationInSeconds = 0; $mailman::mmdm = 0;
$mailman::mmnh = 0; $mailman::mmt = ''; $mailman::mmcz = ''; $mailman::mmcy = '';
$mailman::mmj = ''; $mailman::mmcn = ''; $mailman::mmkp = ''; $mailman::mmz = '';
$mailman::mmaa = ''; $mailman::mmad = ''; $mailman::mmah = ''; $mailman::mmn = '';
$mailman::mmcp = ''; $mailman::mmpz = ''; $mailman::mmlg = ''; $mailman::mmco = '';
$mailman::mmey = ''; $mailman::mmdd = ''; $mailman::mmdb = ''; $mailman::mmdc = '';
$mailman::mmda = ''; $mailman::mmeo = ''; $mailman::mms = '';
$mailman::strLocalLocationUsers = ''; $mailman::strLocalScriptLocation = '';
$mailman::strLocalTemplateLocation = ''; $mailman::mmab = ''; $mailman::mmac = '';
$mailman::mmbk = ''; $mailman::mmcv = ''; $mailman::mmr = ''; $mailman::mman = '';
$mailman::mmft = ''; $mailman::mmap = ''; $mailman::mmam = ''; $mailman::mmao = '';
$mailman::mmav = ''; $mailman::mmnt = ''; $mailman::mmof = ''; $mailman::mmcs = '';
$mailman::mmcq = ''; $mailman::mmep = ''; $mailman::mmcr = ''; $mailman::mmbs = '';
$mailman::mmaz = ''; $mailman::mmcm = ''; $mailman::mmv = ''; $mailman::mmp = '';
unless(defined($ENV{'HTTP_COOKIE'})){$ENV{'HTTP_COOKIE'}='';}
unless(defined($ENV{'HTTP_USER_AGENT'})){$ENV{'HTTP_USER_AGENT'}='Debug';}
unless(defined($ENV{'OS'})){$ENV{'OS'}='';}
unless(defined($ENV{'REMOTE_HOST'})){$ENV{'REMOTE_HOST'}='Debug';}
unless(defined($ENV{'REMOTE_ADDR'})){$ENV{'REMOTE_ADDR'}='Debug';}
unless(defined($ENV{'SCRIPT_NAME'})){$ENV{'SCRIPT_NAME'}='Debug';}
unless(defined($ENV{'SERVER_NAME'})){$ENV{'SERVER_NAME'}='Debug';} }
sub mmtu { my($mmqa) = shift; my($mmd);
for($mmd=0;$mmd<$mailman::iFromDomainTrim;$mmd++) { $mmqa =~ s/^[^\.]+\.(.*)$/$1/;
} return $mmqa; }